@@ -51,16 +51,16 @@ CP=$CLASSPATH:$JETS3T_HOME/configs
 CP=$CP:$JETS3T_HOME/resources
 
 # Include libraries in classpath
-CP=$CP:$JETS3T_HOME/jars/jets3t-0.7.4.jar
-CP=$CP:$JETS3T_HOME/jars/jets3t-gui-0.7.4.jar
-CP=$CP:$JETS3T_HOME/jars/cockpit-0.7.4.jar
+CP=$CP:$JETS3T_HOME/jars/jets3t-0.8.1.jar
+CP=$CP:$JETS3T_HOME/jars/jets3t-gui-0.8.1.jar
+CP=$CP:$JETS3T_HOME/jars/cockpit-0.8.1.jar
 CP=$CP:$JETS3T_HOME/libs/commons-logging/commons-logging-1.1.1.jar
 CP=$CP:$JETS3T_HOME/libs/commons-codec/commons-codec-1.3.jar
 CP=$CP:$JETS3T_HOME/libs/commons-httpclient/commons-httpclient-3.1.jar
 CP=$CP:$JETS3T_HOME/libs/misc/BareBonesBrowserLaunch.jar
 CP=$CP:$JETS3T_HOME/libs/logging-log4j/log4j-1.2.15.jar
 CP=$CP:$JETS3T_HOME/libs/bouncycastle/bcprov-jdk14-138.jar
-CP=$CP:$JETS3T_HOME/libs/java-xmlbuilder/java-xmlbuilder-1.jar
+CP=$CP:$JETS3T_HOME/libs/java-xmlbuilder/java-xmlbuilder-0.4.jar
 
 # Convert classpath for cygwin bash
 case "`uname -s`" in
