@@ -103,6 +103,7 @@ import org.jets3t.gui.HyperlinkActivatedListener;
 import org.jets3t.gui.JHtmlLabel;
 import org.jets3t.gui.UserInputFields;
 import org.jets3t.gui.skins.SkinsFactory;
+import org.jets3t.service.Constants;
 import org.jets3t.service.Jets3tProperties;
 import org.jets3t.service.S3ServiceException;
 import org.jets3t.service.impl.rest.httpclient.RestS3Service;
@@ -141,7 +142,7 @@ import com.centerkey.utils.BareBonesBrowserLaunch;
  * service.
  * <p>
  * For more information and help please see the
- * <a href="http://jets3t.s3.amazonaws.com/applications/uploader.html">Uploader Guide</a>.
+ * <a href="http://www.jets3t.org/applications/uploader.html">Uploader Guide</a>.
  * </p>
  * <p>
  * The Uploader is highly configurable through properties specified in a file
@@ -154,11 +155,11 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
 
     private static final Log log = LogFactory.getLog(Uploader.class);
 
-    public static final String APPLICATION_DESCRIPTION = "Uploader/0.7.4-dev";
+    public static final String APPLICATION_DESCRIPTION = "Uploader/" + Constants.JETS3T_VERSION;
 
     public static final String UPLOADER_PROPERTIES_FILENAME = "uploader.properties";
 
-    private static final String UPLOADER_VERSION_ID = "JetS3t Uploader/0.7.4-dev";
+    private static final String UPLOADER_VERSION_ID = "JetS3t Uploader/" + Constants.JETS3T_VERSION;
 
     public static final int WIZARD_SCREEN_1 = 1;
     public static final int WIZARD_SCREEN_2 = 2;
@@ -320,6 +321,7 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
      * Prepares application to run as a GUI by finding/creating a root owner JFrame, and
      * (if necessary) creating a directory for storing remembered logins.
      */
+    @Override
     public void init() {
         super.init();
 
@@ -1012,6 +1014,7 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
 
             // Monitor generation of MD5 hash, and provide feedback via the progress bar.
             BytesProgressWatcher progressWatcher = new BytesProgressWatcher(filesSizeTotal[0]) {
+                @Override
                 public void updateBytesTransferred(long byteCount) {
                     super.updateBytesTransferred(byteCount);
 
@@ -1377,6 +1380,7 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
 
             cancelUploadButton.setEnabled(false);
             new Thread() {
+                @Override
                 public void run() {
                     uploadFilesToS3();
                 }
