@@ -62,6 +62,7 @@ import org.jets3t.service.model.S3Bucket;
 import org.jets3t.service.model.cloudfront.Distribution;
 import org.jets3t.service.model.cloudfront.DistributionConfig;
 import org.jets3t.service.model.cloudfront.LoggingStatus;
+import org.jets3t.service.model.cloudfront.S3Origin;
 
 /**
  * Dialog box for displaying and modifying CloudFront distributions.
@@ -75,11 +76,11 @@ import org.jets3t.service.model.cloudfront.LoggingStatus;
 public class ManageDistributionsDialog extends JDialog
     implements ActionListener, ListSelectionListener, HyperlinkActivatedListener
 {
-    private static final long serialVersionUID = 8754669642320546085L;
+    private static final long serialVersionUID = 4375982994004017092L;
 
     private CloudFrontService cloudFrontService = null;
 
-    private GuiUtils guiUtils = new GuiUtils();
+    private final GuiUtils guiUtils = new GuiUtils();
 
     private Frame ownerFrame = null;
     private JTable distributionListTable = null;
@@ -89,6 +90,7 @@ public class ManageDistributionsDialog extends JDialog
     private JCheckBox enabledCheckbox = null;
     private JCheckBox httpsOnlyCheckbox = null;
     private JComboBox loggingBucketComboBox = null;
+    private JTextField defaultRootObjectTextField = null;
     private JTextField loggingPrefixTextField = null;
     private JTable cnamesTable = null;
     private CNAMETableModel cnamesTableModel = null;
@@ -117,24 +119,26 @@ public class ManageDistributionsDialog extends JDialog
         distributionListTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
         distributionListTable.getSelectionModel().addListSelectionListener(this);
 
-        JLabel bucketLabel = new JLabel("Bucket:");
+        JLabel bucketLabel = new JLabel("Bucket");
         bucketComboBox = new JComboBox(bucketNames);
-        JLabel enabledLabel = new JLabel("Enabled?");
+        JLabel enabledLabel = new JLabel("Enabled");
         enabledCheckbox = new JCheckBox();
-        JLabel httpsOnlyLabel = new JLabel("HTTPS Only?");
+        JLabel httpsOnlyLabel = new JLabel("HTTPS Only");
         httpsOnlyCheckbox = new JCheckBox();
+        JLabel defaultRootObjectLabel = new JLabel("Default Root Object");
+        defaultRootObjectTextField = new JTextField();
 
-        JLabel loggingBucketLabel = new JLabel("Logging bucket:");
+        JLabel loggingBucketLabel = new JLabel("Logging bucket");
         loggingBucketComboBox = new JComboBox(bucketNames);
         loggingBucketComboBox.insertItemAt("-- Logging Disabled --", 0);
         loggingBucketComboBox.setSelectedIndex(0);
         loggingBucketComboBox.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
-            	loggingPrefixTextField.setEnabled(
-        			loggingBucketComboBox.getSelectedIndex() > 0);
+                loggingPrefixTextField.setEnabled(
+                    loggingBucketComboBox.getSelectedIndex() > 0);
             }
         });
-        JLabel loggingPrefixLabel = new JLabel("Logging prefix:");
+        JLabel loggingPrefixLabel = new JLabel("Logging prefix");
         loggingPrefixTextField = new JTextField();
         loggingPrefixTextField.setEnabled(false);
 
@@ -225,6 +229,10 @@ public class ManageDistributionsDialog extends JDialog
             1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, insetsDefault, 0, 0));
         detailPanel.add(httpsOnlyCheckbox, new GridBagConstraints(1, row++,
             1, 1, 1, 0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, insetsDefault, 0, 0));
+        detailPanel.add(defaultRootObjectLabel, new GridBagConstraints(0, row,
+            1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, insetsDefault, 0, 0));
+        detailPanel.add(defaultRootObjectTextField, new GridBagConstraints(1, row++,
+            1, 1, 1, 0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, insetsDefault, 0, 0));
 
         detailPanel.add(loggingBucketLabel, new GridBagConstraints(0, row,
             1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, insetsDefault, 0, 0));
@@ -272,6 +280,7 @@ public class ManageDistributionsDialog extends JDialog
 
     protected void refreshDistributions() {
         (new Thread() {
+            @Override
             public void run() {
                 final ProgressDialog progressDialog =
                     new ProgressDialog(ownerFrame, "Listing Distributions", null);
@@ -342,6 +351,7 @@ public class ManageDistributionsDialog extends JDialog
                 bucketComboBox.setEnabled(true);
                 enabledCheckbox.setSelected(false);
                 httpsOnlyCheckbox.setEnabled(false);
+                defaultRootObjectTextField.setText("");
 
                 loggingBucketComboBox.setSelectedIndex(0);
                 loggingPrefixTextField.setText("");
@@ -359,21 +369,25 @@ public class ManageDistributionsDialog extends JDialog
                     distributionConfig = cloudFrontService.getDistributionConfig(distribution.getId());
                 } catch (CloudFrontServiceException ex) {
                     String message = "Unable to retrieve configuration information "
-                    	+ "for distribution: " + distribution.getId();
+                        + "for distribution: " + distribution.getId();
                     ErrorDialog.showDialog(ownerFrame, this, message, ex);
                     return;
                 }
 
-                bucketComboBox.setSelectedItem(distribution.getOriginAsBucketName());
+                if (distribution.getOrigin() instanceof S3Origin) {
+                    bucketComboBox.setSelectedItem(
+                        ((S3Origin)distribution.getOrigin()).getOriginAsBucketName());
+                }
                 bucketComboBox.setEnabled(false);
                 enabledCheckbox.setSelected(distribution.isEnabled());
                 httpsOnlyCheckbox.setSelected(distributionConfig.isHttpsProtocolRequired());
+                defaultRootObjectTextField.setText(distributionConfig.getDefaultRootObject());
 
                 if (distributionConfig.getLoggingStatus() != null) {
                     loggingBucketComboBox.setSelectedItem(
-                    	distributionConfig.getLoggingStatus().getShortBucketName());
+                        distributionConfig.getLoggingStatus().getShortBucketName());
                     loggingPrefixTextField.setText(
-                    	distributionConfig.getLoggingStatus().getPrefix());
+                        distributionConfig.getLoggingStatus().getPrefix());
                 } else {
                     loggingBucketComboBox.setSelectedIndex(0);
                     loggingPrefixTextField.setText("");
@@ -423,6 +437,7 @@ public class ManageDistributionsDialog extends JDialog
                 return;
             } else {
                 (new Thread() {
+                    @Override
                     public void run() {
                         final ProgressDialog progressDialog =
                             new ProgressDialog(ownerFrame, "Deleting Distribution", null);
@@ -459,9 +474,10 @@ public class ManageDistributionsDialog extends JDialog
                 }).start();
             }
         } else if (event.getActionCommand().equals("NewDistribution")) {
-            final String origin = bucketComboBox.getSelectedItem() + ".s3.amazonaws.com";
+            final String bucketName = bucketComboBox.getSelectedItem() + ".s3.amazonaws.com";
 
             (new Thread() {
+                @Override
                 public void run() {
                     final ProgressDialog progressDialog =
                         new ProgressDialog(ownerFrame, "Creating Distribution", null);
@@ -476,11 +492,11 @@ public class ManageDistributionsDialog extends JDialog
                     try {
                         LoggingStatus loggingStatus = null;
                         if (loggingBucketComboBox.getSelectedIndex() > 0) {
-                        	String loggingBucket = (String) loggingBucketComboBox.getSelectedItem()
-                        		+ CloudFrontService.DEFAULT_BUCKET_SUFFIX;
-                        	loggingStatus = new LoggingStatus(
-                        			loggingBucket,
-                        			loggingPrefixTextField.getText());
+                            String loggingBucket = (String) loggingBucketComboBox.getSelectedItem()
+                                + CloudFrontService.DEFAULT_BUCKET_SUFFIX;
+                            loggingStatus = new LoggingStatus(
+                                    loggingBucket,
+                                    loggingPrefixTextField.getText());
                         }
 
                         String[] requiredProtocols = null;
@@ -490,13 +506,19 @@ public class ManageDistributionsDialog extends JDialog
                             requiredProtocols = new String[0];
                         }
 
-                        cloudFrontService.createDistribution(origin, null,
+                        String defaultRootObject = defaultRootObjectTextField.getText();
+                        if (defaultRootObject.length() == 0) {
+                            defaultRootObject = null;
+                        }
+
+                        cloudFrontService.createDistribution(
+                            new S3Origin(bucketName), null,
                             cnamesTableModel.getCnames(), commentTextArea.getText(),
                             enabledCheckbox.isSelected(), loggingStatus,
-                            null,  // originAccessIdentityId
                             false, // trustedSignerSelf
                             null,  // trustedSignerAwsAccountNumbers
-                            requiredProtocols);
+                            requiredProtocols,
+                            defaultRootObject);
                         refreshDistributions();
                     } catch (Exception e) {
                         SwingUtilities.invokeLater(new Runnable() {
@@ -524,6 +546,7 @@ public class ManageDistributionsDialog extends JDialog
                     distributionListTable.getSelectedRow()));
 
             (new Thread() {
+                @Override
                 public void run() {
                     final ProgressDialog progressDialog =
                         new ProgressDialog(ownerFrame, "Updating Distribution", null);
@@ -538,11 +561,11 @@ public class ManageDistributionsDialog extends JDialog
                     try {
                         LoggingStatus loggingStatus = null;
                         if (loggingBucketComboBox.getSelectedIndex() > 0) {
-                        	String loggingBucket = (String) loggingBucketComboBox.getSelectedItem()
-                    			+ CloudFrontService.DEFAULT_BUCKET_SUFFIX;
-                        	loggingStatus = new LoggingStatus(
-                        			loggingBucket,
-                        			loggingPrefixTextField.getText());
+                            String loggingBucket = (String) loggingBucketComboBox.getSelectedItem()
+                                + CloudFrontService.DEFAULT_BUCKET_SUFFIX;
+                            loggingStatus = new LoggingStatus(
+                                    loggingBucket,
+                                    loggingPrefixTextField.getText());
                         }
 
                         String[] requiredProtocols = null;
@@ -552,13 +575,19 @@ public class ManageDistributionsDialog extends JDialog
                             requiredProtocols = new String[0];
                         }
 
+                        String defaultRootObject = defaultRootObjectTextField.getText();
+                        if (defaultRootObject.length() == 0) {
+                            defaultRootObject = null;
+                        }
+
                         cloudFrontService.updateDistributionConfig(distribution.getId(),
+                            null, // origin
                             cnamesTableModel.getCnames(), commentTextArea.getText(),
                             enabledCheckbox.isSelected(), loggingStatus,
-                            null,  // originAccessIdentityId
                             false, // trustedSignerSelf
                             null,  // trustedSignerAwsAccountNumbers
-                            requiredProtocols);
+                            requiredProtocols,
+                            defaultRootObject);
                         refreshDistributions();
                     } catch (Exception e) {
                         SwingUtilities.invokeLater(new Runnable() {
@@ -607,7 +636,7 @@ public class ManageDistributionsDialog extends JDialog
     private class DistributionListTableModel extends DefaultTableModel {
         private static final long serialVersionUID = -8315527286580422385L;
 
-        private ArrayList distributionList = new ArrayList();
+        private final ArrayList distributionList = new ArrayList();
 
         private Icon inProgressIcon = null;
         private Icon deployedIcon = null;
@@ -631,7 +660,7 @@ public class ManageDistributionsDialog extends JDialog
             return Collections.binarySearch(
                 distributionList, bucketName, new Comparator() {
                     public int compare(Object o1, Object o2) {
-                        String b1Name = ((Distribution)o1).getOriginAsBucketName();
+                        String b1Name = ((Distribution)o1).getOrigin().getDnsName();
                         String b2Name = (String) o2;
                         int result =  b1Name.compareTo(b2Name);
                         return result;
@@ -645,8 +674,8 @@ public class ManageDistributionsDialog extends JDialog
             this.insertRow(distributionList.size() - 1, new Object[] {
                 (distribution.isDeployed() ? deployedIcon : inProgressIcon),
                 Boolean.valueOf(distribution.isEnabled()),
-                distribution.getOriginAsBucketName(), distribution.getDomainName(),
-            	distribution.getLastModifiedTime()
+                distribution.getOrigin().getDnsName(), distribution.getDomainName(),
+                distribution.getLastModifiedTime()
             });
         }
 
@@ -672,10 +701,12 @@ public class ManageDistributionsDialog extends JDialog
             distributionList.clear();
         }
 
+        @Override
         public boolean isCellEditable(int row, int column) {
             return (column == 3 && row < distributionList.size());
         }
 
+        @Override
         public Class getColumnClass(int columnIndex) {
             switch (columnIndex) {
             case 0: return Icon.class;
@@ -711,6 +742,7 @@ public class ManageDistributionsDialog extends JDialog
             }
         }
 
+        @Override
         public boolean isCellEditable(int row, int column) {
             return true;
         }
