@@ -22,8 +22,10 @@ import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.InputStreamReader;
+import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.List;
 import java.util.Map;
 
 import org.jets3t.service.Constants;
@@ -39,15 +41,18 @@ import org.jets3t.service.model.BaseVersionOrDeleteMarker;
 import org.jets3t.service.model.S3Bucket;
 import org.jets3t.service.model.S3BucketVersioningStatus;
 import org.jets3t.service.model.S3Object;
+import org.jets3t.service.model.StorageObject;
 import org.jets3t.service.multithread.DownloadPackage;
 import org.jets3t.service.multithread.S3ServiceSimpleMulti;
 import org.jets3t.service.security.AWSCredentials;
 import org.jets3t.service.security.AWSDevPayCredentials;
+import org.jets3t.service.security.ProviderCredentials;
+import org.jets3t.service.utils.MultipartUtils;
 import org.jets3t.service.utils.ServiceUtils;
 
 /**
  * This class includes all the code samples as listed in the JetS3t
- * <a href="http://jets3t.s3.amazonaws.com/toolkit/guide.html">Programmer Guide</a>.
+ * <a href="http://www.jets3t.org/toolkit/guide.html">Programmer Guide</a>.
  * <p>
  * This code is provided as a convenience for those who are reading through the guide and don't want
  * to type out the examples themselves.
@@ -57,6 +62,9 @@ import org.jets3t.service.utils.ServiceUtils;
  */
 public class CodeSamples {
 
+    private static final String BUCKET_NAME = "test-bucket";
+    private static final String TEST_OBJECT_NAME = "helloworld.txt";
+
     public static void main(String[] args) throws Exception {
         /* ************
          * Code Samples
@@ -72,17 +80,14 @@ public class CodeSamples {
 
         AWSCredentials awsCredentials = SamplesUtils.loadAWSCredentials();
 
-        // To communicate with S3, create a class that implements an S3Service.
-        // We will use the REST/HTTP implementation based on HttpClient, as this is the most
-        // robust implementation provided with JetS3t.
-
-        S3Service s3Service = new RestS3Service(awsCredentials);
+        // To communicate with S3 use the RestS3Service.
+        RestS3Service s3Service = new RestS3Service(awsCredentials);
 
         // A good test to see if your S3Service can connect to S3 is to list all the buckets you own.
         // If a bucket listing produces no exceptions, all is well.
 
         S3Bucket[] myBuckets = s3Service.listAllBuckets();
-        System.out.println("How many buckets to I have in S3? " + myBuckets.length);
+        System.out.println("How many buckets do I have in S3? " + myBuckets.length);
 
         /*
          * Create a bucket
@@ -90,7 +95,7 @@ public class CodeSamples {
 
         // To store data in S3 you must first create a bucket, a container for objects.
 
-        S3Bucket testBucket = s3Service.createBucket("test-bucket");
+        S3Bucket testBucket = s3Service.createBucket(BUCKET_NAME);
         System.out.println("Created test bucket: " + testBucket.getName());
 
         // If you try using a common name, you will probably not be able to create the
@@ -142,7 +147,7 @@ public class CodeSamples {
         // Create an S3Object based on a string, with Content-Length set automatically and
         // Content-Type set to "text/plain"
         String stringData = "Hello World!";
-        S3Object stringObject = new S3Object("HelloWorld.txt", stringData);
+        S3Object stringObject = new S3Object(TEST_OBJECT_NAME, stringData);
 
         // Create an S3Object based on a file, with Content-Length set automatically and
         // Content-Type set based on the file's extension (using the Mimetypes utility class)
@@ -194,7 +199,7 @@ public class CodeSamples {
         // do this for you automatically when you use the File- or String-based
         // S3Object constructors:
 
-        S3Object objectWithHash = new S3Object("HelloWorld.txt", stringData);
+        S3Object objectWithHash = new S3Object(TEST_OBJECT_NAME, stringData);
         System.out.println("Hash value: " + objectWithHash.getMd5HashAsHex());
 
         // If you do not use these constructors, you should *always* set the
@@ -224,7 +229,7 @@ public class CodeSamples {
         // metadata associated with it such as the Content Type.
 
         // Retrieve the HEAD of the data object we created previously.
-        S3Object objectDetailsOnly = s3Service.getObjectDetails(testBucket, "helloWorld.txt");
+        S3Object objectDetailsOnly = s3Service.getObjectDetails(testBucket, TEST_OBJECT_NAME);
         System.out.println("S3Object, details only: " + objectDetailsOnly);
 
         // If you need the data contents of the object, the getObject method will return all the
@@ -232,7 +237,7 @@ public class CodeSamples {
         // the object's data can be read.
 
         // Retrieve the whole data object we created previously
-        S3Object objectComplete = s3Service.getObject(testBucket, "helloWorld.txt");
+        S3Object objectComplete = s3Service.getObject(testBucket, TEST_OBJECT_NAME);
         System.out.println("S3Object, complete: " + objectComplete);
 
         // Read the data from the object's DataInputStream using a loop, and print it out.
@@ -255,7 +260,7 @@ public class CodeSamples {
         // JetS3t provides convenient methods for verifying data that has been
         // downloaded to a File, byte array or InputStream.
 
-        S3Object downloadedObject = s3Service.getObject(testBucket, "helloWorld.txt");
+        S3Object downloadedObject = s3Service.getObject(testBucket, TEST_OBJECT_NAME);
         String textData = ServiceUtils.readInputStreamToString(
             downloadedObject.getDataInputStream(), "UTF-8");
         boolean valid = downloadedObject.verifyData(textData.getBytes("UTF-8"));
@@ -307,15 +312,15 @@ public class CodeSamples {
         // Copy an existing source object to the target S3Object
         // This will copy the source's object data and metadata to the target object.
         boolean replaceMetadata = false;
-        s3Service.copyObject("test-bucket", "HelloWorld.txt", "destination-bucket", targetObject, replaceMetadata);
+        s3Service.copyObject(BUCKET_NAME, TEST_OBJECT_NAME, "destination-bucket", targetObject, replaceMetadata);
 
         // You can also copy an object and update its metadata at the same time. Perform a
         // copy-in-place  (with the same bucket and object names for source and destination)
         // to update an object's metadata while leaving the object's data unchanged.
-        targetObject = new S3Object("HelloWorld.txt");
+        targetObject = new S3Object(TEST_OBJECT_NAME);
         targetObject.addMetadata(S3Object.METADATA_HEADER_CONTENT_TYPE, "text/html");
         replaceMetadata = true;
-        s3Service.copyObject("test-bucket", "HelloWorld.txt", "test-bucket", targetObject, replaceMetadata);
+        s3Service.copyObject(BUCKET_NAME, TEST_OBJECT_NAME, BUCKET_NAME, targetObject, replaceMetadata);
 
         /*
          * Moving and Renaming objects
@@ -328,13 +333,13 @@ public class CodeSamples {
         // operation fails, the object will exist in both the source and destination locations.
 
         // Here is a command that moves an object from one bucket to another.
-        s3Service.moveObject("test-bucket", "HelloWorld.txt", "destination-bucket", targetObject, false);
+        s3Service.moveObject(BUCKET_NAME, TEST_OBJECT_NAME, "destination-bucket", targetObject, false);
 
         // You can move an object to a new name in the same bucket. This is essentially a rename operation.
-        s3Service.moveObject("test-bucket", "HelloWorld.txt", "test-bucket", new S3Object("NewName.txt"), false);
+        s3Service.moveObject(BUCKET_NAME, TEST_OBJECT_NAME, BUCKET_NAME, new S3Object("NewName.txt"), false);
 
         // To make renaming easier, JetS3t has a shortcut method especially for this purpose.
-        s3Service.renameObject("test-bucket", "HelloWorld.txt", targetObject);
+        s3Service.renameObject(BUCKET_NAME, TEST_OBJECT_NAME, targetObject);
 
         /*
          * Deleting objects and buckets
@@ -369,8 +374,8 @@ public class CodeSamples {
         // The JetS3t Toolkit includes utility services, S3ServiceMulti and S3ServiceSimpleMulti, that
         // can perform an S3 operation on many objects at a time. These services allow you to use more
         // of your available bandwidth and perform S3 operations much faster. They work with any
-        // thread-safe S3Service implementation, such as the HTTP/REST and SOAP implementations
-        // provided with JetS3t.
+        // thread-safe S3Service implementation, such as the HTTP/REST implementation provided with
+        // JetS3t.
 
         // The S3ServiceMulti service is intended for advanced developers. It is designed for use in
         // graphical applications and uses an event-notification approach to communicate its results
@@ -666,7 +671,7 @@ public class CodeSamples {
         awsCredentials.save("password", credFile);
 
         // Load encrypted credentials from a file.
-        AWSCredentials loadedCredentials = AWSCredentials.load("password", credFile);
+        ProviderCredentials loadedCredentials = AWSCredentials.load("password", credFile);
         System.out.println("AWS Key loaded from file: " + loadedCredentials.getAccessKey());
 
         // You won't get far if you use the wrong password...
@@ -737,6 +742,33 @@ public class CodeSamples {
         acl.grantPermission(new CanonicalGrantee("AWS member's ID"),
             Permission.PERMISSION_WRITE_ACP);
 
+        /*
+         * Bucket Policies -- offer a greater degree of access control for a bucket.
+         */
+
+        // Set a bucket policy that allows public read access to all objects under
+        // the virtual path "/public"
+
+        String bucketNameForPolicy = publicBucket.getName();
+        String policyJSON =
+            "{"
+            + "\"Version\":\"2008-10-17\""
+            + ",\"Id\":\"EXAMPLE\""
+            + ",\"Statement\": [{"
+                + "\"Effect\":\"Allow\""
+                + ",\"Action\":[\"s3:GetObject*\"]"
+                + ",\"Principal\":{\"AWS\": [\"*\"]}"
+                + ",\"Resource\":\"arn:aws:s3:::" + bucketNameForPolicy + "/public/*\""
+            + "}]}";
+        s3Service.setBucketPolicy(bucketNameForPolicy, policyJSON);
+
+        // Retrieve the policy document applied to a bucket
+        String policyDocument = s3Service.getBucketPolicy(bucketNameForPolicy);
+        System.out.println(policyDocument);
+
+        // Delete the policy document applied to a bucket
+        s3Service.deleteBucketPolicy(bucketNameForPolicy);
+
 
         /*
          * Temporarily make an Object available to anyone
@@ -766,6 +798,43 @@ public class CodeSamples {
             privateBucket.getName(), privateObject.getKey(), expiryDate, false);
         System.out.println("Signed URL: " + signedUrl);
 
+        /*
+         * Multipart uploads
+         */
+
+        // Amazon S3 offers an alternative method for uploading objects for
+        // users with advanced requirements, called Multipart Uploads. This
+        // mechanism involves uploading an object's data in parts instead of
+        // all at once, which can give the following advantages:
+        //  * large files can be uploaded in smaller pieces to reduce the
+        //    impact of transient uploading/networking errors
+        //  * objects larger than 5 GB can be stored
+        //  * objects can be constructed from data that is uploaded over a
+        //    period of time, when it may not all be available in advance.
+
+        // JetS3t's MultipartUtils class makes it easy to perform mutipart
+        // uploads of your files. To upload a file in 20MB parts:
+
+        S3Object largeFileObject = new S3Object(new File("/path/to/large/file"));
+
+        List<StorageObject> objectsToUploadAsMultipart = new ArrayList<StorageObject>();
+        objectsToUploadAsMultipart.add(largeFileObject);
+
+        long maxSizeForAPartInBytes = 20 * 1024 * 1024;
+        MultipartUtils mpUtils = new MultipartUtils(maxSizeForAPartInBytes);
+
+        mpUtils.uploadObjects(BUCKET_NAME, s3Service, objectsToUploadAsMultipart,
+            null // eventListener : Provide one to monitor the upload progress
+            );
+
+        // The S3Service API also provides the underlying low-level multipart operations
+        // if you need more control over the process. See the method names that
+        // start with "multipart", and the example code in
+        // TestRestS3Service#testMultipartUploads
+
+        // IMPORTANT: The objects in S3 created by a multipart upload process do not
+        // have ETag header values that can be used to perform MD5 hash verification
+        // of the object data. See https://forums.aws.amazon.com/thread.jspa?messageID=234579
 
         /*
          * Create an S3 POST form
@@ -793,7 +862,6 @@ public class CodeSamples {
 
         // We will now create a POST form with a range of policy conditions,
         // that will allow users to upload image files to a protected bucket.
-        String bucketName = "test-bucket";
         String key = "uploads/images/pic.jpg";
 
         // Specify input fields to set the access permissions and content type
@@ -812,7 +880,7 @@ public class CodeSamples {
         // Note that our list of conditions must include a condition
         // corresponding to each of the additional input fields we specified above.
         String[] conditions = {
-            S3Service.generatePostPolicyCondition_Equality("bucket", bucketName),
+            S3Service.generatePostPolicyCondition_Equality("bucket", BUCKET_NAME),
             S3Service.generatePostPolicyCondition_Equality("key", key),
             S3Service.generatePostPolicyCondition_Range(10240, 204800),
             // Conditions to allow the additional fields specified above
@@ -828,7 +896,7 @@ public class CodeSamples {
 
         // Generate the form.
         String restrictedForm = S3Service.buildPostForm(
-            bucketName, key, awsCredentials, expiration, conditions,
+            BUCKET_NAME, key, awsCredentials, expiration, conditions,
             inputFields, null, true);
 
         /*
@@ -841,18 +909,14 @@ public class CodeSamples {
         // such that the individual who sends requests to a bucket is charged
         // the S3 request and data transfer fees, instead of the bucket's owner.
 
-        // Note: Only the S3 REST API supports the Requester Pays feature, so
-        // you must use a RestS3Service for all the operations described below.
-        // The SoapS3Service will not work.
-
         // Set a bucket to be Requester Pays
-        s3Service.setRequesterPaysBucket(bucketName, true);
+        s3Service.setRequesterPaysBucket(BUCKET_NAME, true);
 
         // Set a bucket to be Owner pays (the default value for S3 buckets)
-        s3Service.setRequesterPaysBucket(bucketName, false);
+        s3Service.setRequesterPaysBucket(BUCKET_NAME, false);
 
         // Find out whether a bucket is configured as Requester pays
-        s3Service.isRequesterPaysBucket(bucketName);
+        s3Service.isRequesterPaysBucket(BUCKET_NAME);
 
         /*
          * Access a Requester Pays bucket when you are not the bucket's owner
@@ -891,7 +955,7 @@ public class CodeSamples {
         boolean isDnsBucketNamingDisabled = false;
 
         String requesterPaysSignedGetUrl =
-            s3Service.createSignedUrl("GET", bucketName, "object-name",
+            s3Service.createSignedUrl("GET", BUCKET_NAME, "object-name",
                 Constants.REQUESTER_PAYS_BUCKET_FLAG, // Include Requester Pays flag
                 httpHeaders, expirySecsAfterEpoch,
                 isVirtualHost, isHttpsUrl,
@@ -916,7 +980,7 @@ public class CodeSamples {
         devPayService.listAllBuckets();
 
         // You can also generate signed URLs for DevPay S3 accounts. Here is the
-        // code to generate a linke that makes an object in a DevPay account
+        // code to generate a link that makes an object in a DevPay account
         // temporary available for public download.
 
         cal = Calendar.getInstance();
