@@ -28,14 +28,20 @@ import java.io.File;
  */
 public class Constants {
 
+    /**
+     * The JetS3t suite version number implemented by this service.
+     */
+    public static final String JETS3T_VERSION = "0.8.1";
+
     public static String S3_DEFAULT_HOSTNAME = "s3.amazonaws.com";
+    public static String GS_DEFAULT_HOSTNAME = "commondatastorage.googleapis.com";
 
     ////////////////////////////////////
     // Default file names and locations.
     ////////////////////////////////////
 
     /**
-     * The name of the <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html#jets3t">JetS3t properties</a>
+     * The name of the <a href="http://www.jets3t.org/toolkit/configuration.html#jets3t">JetS3t properties</a>
      * file: jets3t.properties
      */
     public static String JETS3T_PROPERTIES_FILENAME = "jets3t.properties";
@@ -58,7 +64,7 @@ public class Constants {
     public static String DEVPAY_PRODUCT_TOKEN_PROP_SUFFIX = ".token";
 
     /**
-     * The name of the <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html#ignore">JetS3t ignore</a>
+     * The name of the <a href="http://www.jets3t.org/toolkit/configuration.html#ignore">JetS3t ignore</a>
      * file: .jets3t-ignore
      */
     public static String JETS3T_IGNORE_FILENAME = ".jets3t-ignore";
@@ -155,13 +161,4 @@ public class Constants {
     public static final String AMZ_DELETE_MARKER = "x-amz-delete-marker";
     public static final String AMZ_MULTI_FACTOR_AUTH_CODE = "x-amz-mfa";
 
-    ///////////////////////////////////
-    // Headers used by SOAP S3 Services
-    ///////////////////////////////////
-
-    /**
-     * SOAP service name: AmazonS3
-     */
-    public static final String SOAP_SERVICE_NAME = "AmazonS3";
-
 }
