@@ -39,7 +39,7 @@ import org.apache.commons.logging.LogFactory;
  * </p>
  * <p>
  * For more information about JetS3t properties please see:
- * <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html">JetS3t Configuration</a>
+ * <a href="http://www.jets3t.org/toolkit/configuration.html">JetS3t Configuration</a>
  *
  * @author James Murty
  */
@@ -51,7 +51,8 @@ public class Jets3tProperties implements Serializable {
     /**
      * Stores the jets3t properties.
      */
-    private static final Hashtable propertiesHashtable = new Hashtable();
+    private static final Hashtable<String, Jets3tProperties> propertiesHashtable =
+        new Hashtable<String, Jets3tProperties>();
 
     private Properties properties = new Properties();
     private boolean loaded = false;
@@ -78,7 +79,7 @@ public class Jets3tProperties implements Serializable {
 
         // Keep static references to properties classes by propertiesIdentifer.
         if (propertiesHashtable.containsKey(propertiesIdentifer)) {
-            jets3tProperties = (Jets3tProperties) propertiesHashtable.get(propertiesIdentifer);
+            jets3tProperties = propertiesHashtable.get(propertiesIdentifer);
         } else {
             jets3tProperties = new Jets3tProperties();
             propertiesHashtable.put(propertiesIdentifer, jets3tProperties);
@@ -103,7 +104,7 @@ public class Jets3tProperties implements Serializable {
 
         // Keep static references to properties classes by filename.
         if (propertiesHashtable.containsKey(propertiesFileName)) {
-            jets3tProperties = (Jets3tProperties) propertiesHashtable.get(propertiesFileName);
+            jets3tProperties = propertiesHashtable.get(propertiesFileName);
             return jets3tProperties;
         } else {
             jets3tProperties = new Jets3tProperties();
@@ -122,9 +123,13 @@ public class Jets3tProperties implements Serializable {
                     "Resource '" + propertiesFileName + "' in classpath");
             } catch (IOException e) {
                 if (log.isErrorEnabled()) {
-                	log.error("Failed to load properties from resource in classpath: "
-                		+ propertiesFileName, e);
+                    log.error("Failed to load properties from resource in classpath: "
+                        + propertiesFileName, e);
                 }
+            } finally {
+                try {
+                    cpIS.close();
+                } catch (Exception ignored) {}
             }
         }
         return jets3tProperties;
@@ -199,8 +204,6 @@ public class Jets3tProperties implements Serializable {
      * a name for the source of the properties, such as a properties file name or identifier. This
      * is only used to generate meaningful debug messages when properties are updated, so it is
      * possible to tell where the updated property value came from.
-     *
-     * @throws IOException
      */
     public void loadAndReplaceProperties(Jets3tProperties properties, String propertiesSource) {
         Properties newProperties = properties.getProperties();
@@ -217,13 +220,11 @@ public class Jets3tProperties implements Serializable {
      * a name for the source of the properties, such as a properties file name or identifier. This
      * is only used to generate meaningful debug messages when properties are updated, so it is
      * possible to tell where the updated property value came from.
-     *
-     * @throws IOException
      */
     public void loadAndReplaceProperties(Properties newProperties, String propertiesSource) {
-        Iterator propsIter = newProperties.entrySet().iterator();
+        Iterator<Map.Entry<Object, Object>> propsIter = newProperties.entrySet().iterator();
         while (propsIter.hasNext()) {
-            Map.Entry entry = (Map.Entry) propsIter.next();
+            Map.Entry<Object, Object> entry = propsIter.next();
             String propertyName = (String) entry.getKey();
             String propertyValue = (String) entry.getValue();
             if (properties.containsKey(propertyName) && !properties.getProperty(propertyName).equals(propertyValue)) {
