@@ -18,6 +18,12 @@
  */
 package org.jets3t.service.acl;
 
+import com.jamesmurty.utils.XMLBuilder;
+
+import javax.xml.parsers.FactoryConfigurationError;
+import javax.xml.parsers.ParserConfigurationException;
+import javax.xml.transform.TransformerException;
+
 /**
  * Represents a Group grantee.
  * <p>
@@ -48,7 +54,7 @@ public class GroupGrantee implements GranteeInterface {
      */
     public static final GroupGrantee LOG_DELIVERY = new GroupGrantee("http://acs.amazonaws.com/groups/s3/LogDelivery");
 
-    private String uri = null;
+    protected String id = null;
 
     public GroupGrantee() {
     }
@@ -62,40 +68,52 @@ public class GroupGrantee implements GranteeInterface {
      * @param groupUri
      */
     public GroupGrantee(String groupUri) {
-    	this.uri = groupUri;
+        this.id = groupUri;
     }
 
-    public String toXml() {
-    	return "<Grantee xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:type=\"Group\"><URI>" + uri + "</URI></Grantee>";
+    public String toXml() throws TransformerException,
+        ParserConfigurationException, FactoryConfigurationError
+    {
+        return toXMLBuilder().asString();
+    }
+
+    public XMLBuilder toXMLBuilder() throws TransformerException,
+        ParserConfigurationException, FactoryConfigurationError
+    {
+        return (XMLBuilder.create("Grantee")
+            .attr("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance")
+            .attr("xsi:type", "Group")
+            .element("URI").text(id)
+            );
     }
 
     /**
      * Set the group grantee's URI.
      */
     public void setIdentifier(String uri) {
-    	this.uri = uri;
+        this.id = uri;
     }
 
     /**
      * Returns the group grantee's URI.
      */
     public String getIdentifier() {
-    	return uri;
+        return id;
     }
 
     public String toString() {
-    	return "GroupGrantee [" + uri + "]";
+        return "GroupGrantee [" + id + "]";
     }
 
     public boolean equals(Object obj) {
-    	if (obj instanceof GroupGrantee) {
-    		return uri.equals(((GroupGrantee)obj).uri);
-    	}
-    	return false;
+        if (obj instanceof GroupGrantee) {
+            return id.equals(((GroupGrantee)obj).id);
+        }
+        return false;
     }
 
     public int hashCode() {
-    	return uri.hashCode();
+        return id.hashCode();
     }
 
 }
