@@ -22,7 +22,6 @@ import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
-import java.lang.reflect.Method;
 import java.text.ParseException;
 import java.util.ArrayList;
 import java.util.Date;
@@ -36,20 +35,24 @@ import org.jets3t.service.CloudFrontServiceException;
 import org.jets3t.service.Constants;
 import org.jets3t.service.Jets3tProperties;
 import org.jets3t.service.S3ServiceException;
+import org.jets3t.service.ServiceException;
+import org.jets3t.service.model.cloudfront.CustomOrigin;
 import org.jets3t.service.model.cloudfront.Distribution;
 import org.jets3t.service.model.cloudfront.DistributionConfig;
+import org.jets3t.service.model.cloudfront.Invalidation;
+import org.jets3t.service.model.cloudfront.InvalidationList;
+import org.jets3t.service.model.cloudfront.InvalidationSummary;
 import org.jets3t.service.model.cloudfront.LoggingStatus;
+import org.jets3t.service.model.cloudfront.Origin;
 import org.jets3t.service.model.cloudfront.OriginAccessIdentity;
 import org.jets3t.service.model.cloudfront.OriginAccessIdentityConfig;
+import org.jets3t.service.model.cloudfront.S3Origin;
 import org.jets3t.service.model.cloudfront.StreamingDistribution;
 import org.jets3t.service.model.cloudfront.StreamingDistributionConfig;
 import org.jets3t.service.utils.ServiceUtils;
-import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
-import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
 import org.xml.sax.helpers.DefaultHandler;
-import org.xml.sax.helpers.XMLReaderFactory;
 
 /**
  * XML Sax parser to read XML documents returned by the CloudFront service via
@@ -71,11 +74,15 @@ public class CloudFrontXmlResponsesSaxParser {
      *
      * @throws S3ServiceException
      */
-    public CloudFrontXmlResponsesSaxParser(Jets3tProperties properties) throws S3ServiceException {
+    public CloudFrontXmlResponsesSaxParser(Jets3tProperties properties) throws ServiceException {
         this.properties = properties;
         this.xr = ServiceUtils.loadXMLReader();
     }
 
+    public Jets3tProperties getProperties() {
+        return this.properties;
+    }
+
     /**
      * Parses an XML document from an input stream using a document handler.
      * @param handler
@@ -90,7 +97,7 @@ public class CloudFrontXmlResponsesSaxParser {
     {
         try {
             if (log.isDebugEnabled()) {
-            	log.debug("Parsing XML response document with handler: " + handler.getClass());
+                log.debug("Parsing XML response document with handler: " + handler.getClass());
             }
             BufferedReader breader = new BufferedReader(new InputStreamReader(inputStream,
                 Constants.DEFAULT_ENCODING));
@@ -102,7 +109,7 @@ public class CloudFrontXmlResponsesSaxParser {
                 inputStream.close();
             } catch (IOException e) {
                 if (log.isErrorEnabled()) {
-                	log.error("Unable to close response InputStream up after XML parse failure", e);
+                    log.error("Unable to close response InputStream up after XML parse failure", e);
                 }
             }
             throw new CloudFrontServiceException("Failed to parse XML document with handler "
@@ -116,12 +123,12 @@ public class CloudFrontXmlResponsesSaxParser {
      * XML data input stream.
      * @return
      * the XML handler object populated with data parsed from the XML stream.
-     * @throws S3ServiceException
+     * @throws CloudFrontServiceException
      */
-    public ListDistributionListHandler parseDistributionListResponse(InputStream inputStream)
+    public DistributionListHandler parseDistributionListResponse(InputStream inputStream)
         throws CloudFrontServiceException
     {
-        ListDistributionListHandler handler = new ListDistributionListHandler();
+        DistributionListHandler handler = new DistributionListHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
@@ -129,7 +136,7 @@ public class CloudFrontXmlResponsesSaxParser {
     public DistributionHandler parseDistributionResponse(InputStream inputStream)
         throws CloudFrontServiceException
     {
-        DistributionHandler handler = new DistributionHandler();
+        DistributionHandler handler = new DistributionHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
@@ -137,40 +144,55 @@ public class CloudFrontXmlResponsesSaxParser {
     public DistributionConfigHandler parseDistributionConfigResponse(InputStream inputStream)
         throws CloudFrontServiceException
     {
-        DistributionConfigHandler handler = new DistributionConfigHandler();
+        DistributionConfigHandler handler = new DistributionConfigHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
 
     public OriginAccessIdentityHandler parseOriginAccessIdentity(
-    	InputStream inputStream) throws CloudFrontServiceException
+        InputStream inputStream) throws CloudFrontServiceException
     {
-        OriginAccessIdentityHandler handler = new OriginAccessIdentityHandler();
+        OriginAccessIdentityHandler handler = new OriginAccessIdentityHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
 
     public OriginAccessIdentityConfigHandler parseOriginAccessIdentityConfig(
-    	InputStream inputStream) throws CloudFrontServiceException
+        InputStream inputStream) throws CloudFrontServiceException
     {
-        OriginAccessIdentityConfigHandler handler = new OriginAccessIdentityConfigHandler();
+        OriginAccessIdentityConfigHandler handler = new OriginAccessIdentityConfigHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
 
     public OriginAccessIdentityListHandler parseOriginAccessIdentityListResponse(
-    	InputStream inputStream) throws CloudFrontServiceException
+        InputStream inputStream) throws CloudFrontServiceException
     {
-        OriginAccessIdentityListHandler handler = new OriginAccessIdentityListHandler();
+        OriginAccessIdentityListHandler handler = new OriginAccessIdentityListHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
 
+    public InvalidationHandler parseInvalidationResponse(
+        InputStream inputStream) throws CloudFrontServiceException
+    {
+        InvalidationHandler handler = new InvalidationHandler(xr);
+        parseXmlInputStream(handler, inputStream);
+        return handler;
+    }
+
+    public InvalidationListHandler parseInvalidationListResponse(
+        InputStream inputStream) throws CloudFrontServiceException
+    {
+        InvalidationListHandler handler = new InvalidationListHandler(xr);
+        parseXmlInputStream(handler, inputStream);
+        return handler;
+    }
 
     public ErrorHandler parseErrorResponse(InputStream inputStream)
         throws CloudFrontServiceException
     {
-        ErrorHandler handler = new ErrorHandler();
+        ErrorHandler handler = new ErrorHandler(xr);
         parseXmlInputStream(handler, inputStream);
         return handler;
     }
@@ -179,68 +201,6 @@ public class CloudFrontXmlResponsesSaxParser {
     // Handlers //
     // ////////////
 
-    public class SimpleHandler extends DefaultHandler {
-        private StringBuffer textContent = null;
-        protected SimpleHandler currentHandler = null;
-        protected SimpleHandler parentHandler = null;
-
-        public SimpleHandler() {
-            this.textContent = new StringBuffer();
-            currentHandler = this;
-        }
-
-        public void transferControlToHandler(SimpleHandler toHandler) {
-            currentHandler = toHandler;
-            toHandler.parentHandler = this;
-        }
-
-        public void returnControlToParentHandler() {
-            if (isChildHandler()) {
-                parentHandler.currentHandler = parentHandler;
-                parentHandler.controlReturned(this);
-            } else {
-                log.debug("Ignoring call to return control to parent handler, as this class has no parent: " +
-                    this.getClass().getName());
-            }
-        }
-
-        public boolean isChildHandler() {
-            return parentHandler != null;
-        }
-
-        public void controlReturned(SimpleHandler childHandler) {}
-
-        public void startElement(String uri, String name, String qName, Attributes attrs) {
-            try {
-                Method method = currentHandler.getClass().getMethod("start" + name, new Class[] {});
-                method.invoke(currentHandler, new Object[] {});
-            } catch (NoSuchMethodException e) {
-                log.debug("Skipped non-existent SimpleHandler subclass's startElement method for '" + name + "' in " + this.getClass().getName());
-            } catch (Throwable t) {
-                log.error("Unable to invoke SimpleHandler subclass's startElement method for '" + name + "' in " + this.getClass().getName(), t);
-            }
-        }
-
-        public void endElement(String uri, String name, String qName) {
-            String elementText = this.textContent.toString().trim();
-            try {
-                Method method = currentHandler.getClass().getMethod("end" + name, new Class[] {String.class});
-                method.invoke(currentHandler, new Object[] {elementText});
-            } catch (NoSuchMethodException e) {
-                log.debug("Skipped non-existent SimpleHandler subclass's endElement method for '" + name + "' in " + this.getClass().getName());
-            } catch (Throwable t) {
-                log.error("Unable to invoke SimpleHandler subclass's endElement method for '" + name + "' in " + this.getClass().getName(), t);
-            }
-            this.textContent = new StringBuffer();
-        }
-
-        public void characters(char ch[], int start, int length) {
-            this.textContent.append(ch, start, length);
-        }
-
-
-    }
-
     public class DistributionHandler extends SimpleHandler {
         private Distribution distribution = null;
 
@@ -248,11 +208,16 @@ public class CloudFrontXmlResponsesSaxParser {
         private String status = null;
         private Date lastModifiedTime = null;
         private String domainName = null;
-        private Map activeTrustedSigners = new HashMap();
+        private final Map<String, List<String>> activeTrustedSigners =
+            new HashMap<String, List<String>>();
 
         private boolean inSignerElement;
         private String lastSignerIdentifier = null;
 
+        public DistributionHandler(XMLReader xr) {
+            super(xr);
+        }
+
         public Distribution getDistribution() {
             return distribution;
         }
@@ -285,36 +250,37 @@ public class CloudFrontXmlResponsesSaxParser {
 
         public void endSelf(String text) {
             if (inSignerElement) {
-            	lastSignerIdentifier = "Self";
+                lastSignerIdentifier = "Self";
             }
         }
 
         public void endAwsAccountNumber(String text) {
             if (inSignerElement) {
-            	lastSignerIdentifier = text;
+                lastSignerIdentifier = text;
             }
         }
 
         public void endKeyPairId(String text) {
             if (inSignerElement) {
-            	List keypairIdList = (List) activeTrustedSigners.get(lastSignerIdentifier);
-            	if (keypairIdList == null) {
-            		keypairIdList = new ArrayList();
-                	activeTrustedSigners.put(lastSignerIdentifier, keypairIdList);
-            	}
-            	keypairIdList.add(text);
+                List<String> keypairIdList = activeTrustedSigners.get(lastSignerIdentifier);
+                if (keypairIdList == null) {
+                    keypairIdList = new ArrayList<String>();
+                    activeTrustedSigners.put(lastSignerIdentifier, keypairIdList);
+                }
+                keypairIdList.add(text);
             }
         }
         // End handle ActiveTrustedSigner elements //
 
         public void startDistributionConfig() {
-            transferControlToHandler(new DistributionConfigHandler());
+            transferControlToHandler(new DistributionConfigHandler(xr));
         }
 
         public void startStreamingDistributionConfig() {
-            transferControlToHandler(new DistributionConfigHandler());
+            transferControlToHandler(new DistributionConfigHandler(xr));
         }
 
+        @Override
         public void controlReturned(SimpleHandler childHandler) {
             DistributionConfig config =
                 ((DistributionConfigHandler) childHandler).getDistributionConfig();
@@ -341,29 +307,42 @@ public class CloudFrontXmlResponsesSaxParser {
     public class DistributionConfigHandler extends SimpleHandler {
         private DistributionConfig distributionConfig = null;
 
-        private String origin = "";
         private String callerReference = "";
-        private List cnamesList = new ArrayList();
+        private Origin origin = null;
+        private final List<String> cnamesList = new ArrayList<String>();
         private String comment = "";
         private boolean enabled = false;
         private LoggingStatus loggingStatus = null;
-        private String originAccessIdentity = null;
         private boolean trustedSignerSelf = false;
-        private List trustedSignerAwsAccountNumberList = new ArrayList();
-        private List requiredProtocols = new ArrayList();
+        private final List<String> trustedSignerAwsAccountNumberList = new ArrayList<String>();
+        private final List<String> requiredProtocols = new ArrayList<String>();
+        private String defaultRootObject = null;
+
+        public DistributionConfigHandler(XMLReader xr) {
+            super(xr);
+        }
 
         public DistributionConfig getDistributionConfig() {
             return distributionConfig;
         }
 
-        public void endOrigin(String text) {
-            this.origin = text;
-        }
-
         public void endCallerReference(String text) {
             this.callerReference = text;
         }
 
+        public void startS3Origin() {
+            transferControlToHandler(new OriginHandler(xr));
+        }
+
+        public void startCustomOrigin() {
+            transferControlToHandler(new OriginHandler(xr));
+        }
+
+        @Override
+        public void controlReturned(SimpleHandler childHandler) {
+            this.origin = ((OriginHandler) childHandler).origin;
+        }
+
         public void endCNAME(String text) {
             this.cnamesList.add(text);
         }
@@ -388,10 +367,6 @@ public class CloudFrontXmlResponsesSaxParser {
             this.loggingStatus.setPrefix(text);
         }
 
-        public void endOriginAccessIdentity(String text) {
-            this.originAccessIdentity = text;
-        }
-
         public void endSelf(String text) {
             this.trustedSignerSelf = true;
         }
@@ -404,15 +379,20 @@ public class CloudFrontXmlResponsesSaxParser {
             this.requiredProtocols.add(text);
         }
 
+        public void endDefaultRootObject(String text) {
+            this.defaultRootObject = text;
+        }
+
         public void endDistributionConfig(String text) {
             this.distributionConfig = new DistributionConfig(
                 origin, callerReference,
-                (String[]) cnamesList.toArray(new String[cnamesList.size()]),
-                comment, enabled, loggingStatus, originAccessIdentity, trustedSignerSelf,
-                (String[]) trustedSignerAwsAccountNumberList.toArray(
-                	new String[trustedSignerAwsAccountNumberList.size()]),
-                (String[]) requiredProtocols.toArray(
-                    new String[requiredProtocols.size()])
+                cnamesList.toArray(new String[cnamesList.size()]),
+                comment, enabled, loggingStatus, trustedSignerSelf,
+                trustedSignerAwsAccountNumberList.toArray(
+                    new String[trustedSignerAwsAccountNumberList.size()]),
+                requiredProtocols.toArray(
+                    new String[requiredProtocols.size()]),
+                    defaultRootObject
                 );
             returnControlToParentHandler();
         }
@@ -420,11 +400,11 @@ public class CloudFrontXmlResponsesSaxParser {
         public void endStreamingDistributionConfig(String text) {
             this.distributionConfig = new StreamingDistributionConfig(
                 origin, callerReference,
-                (String[]) cnamesList.toArray(new String[cnamesList.size()]), comment,
-                enabled, loggingStatus, originAccessIdentity, trustedSignerSelf,
-                (String[]) trustedSignerAwsAccountNumberList.toArray(
+                cnamesList.toArray(new String[cnamesList.size()]), comment,
+                enabled, loggingStatus, trustedSignerSelf,
+                trustedSignerAwsAccountNumberList.toArray(
                     new String[trustedSignerAwsAccountNumberList.size()]),
-                (String[]) requiredProtocols.toArray(
+                requiredProtocols.toArray(
                     new String[requiredProtocols.size()])
                 );
             returnControlToParentHandler();
@@ -438,11 +418,15 @@ public class CloudFrontXmlResponsesSaxParser {
         private String status = null;
         private Date lastModifiedTime = null;
         private String domainName = null;
-        private String origin = null;
-        private List cnamesList = new ArrayList();
+        private Origin origin = null;
+        private final List<String> cnamesList = new ArrayList<String>();
         private String comment = null;
         private boolean enabled = false;
 
+        public DistributionSummaryHandler(XMLReader xr) {
+            super(xr);
+        }
+
         public Distribution getDistribution() {
             return distribution;
         }
@@ -463,8 +447,17 @@ public class CloudFrontXmlResponsesSaxParser {
             this.domainName = text;
         }
 
-        public void endOrigin(String text) {
-            this.origin = text;
+        public void startS3Origin() {
+            transferControlToHandler(new OriginHandler(xr));
+        }
+
+        public void startCustomOrigin() {
+            transferControlToHandler(new OriginHandler(xr));
+        }
+
+        @Override
+        public void controlReturned(SimpleHandler childHandler) {
+            this.origin = ((OriginHandler) childHandler).origin;
         }
 
         public void endCNAME(String text) {
@@ -482,7 +475,7 @@ public class CloudFrontXmlResponsesSaxParser {
         public void endDistributionSummary(String text) {
             this.distribution = new Distribution(id, status,
                 lastModifiedTime, domainName, origin,
-                (String[]) cnamesList.toArray(new String[cnamesList.size()]),
+                cnamesList.toArray(new String[cnamesList.size()]),
                 comment, enabled);
             returnControlToParentHandler();
         }
@@ -490,21 +483,25 @@ public class CloudFrontXmlResponsesSaxParser {
         public void endStreamingDistributionSummary(String text) {
             this.distribution = new StreamingDistribution(id, status,
                 lastModifiedTime, domainName, origin,
-                (String[]) cnamesList.toArray(new String[cnamesList.size()]),
+                cnamesList.toArray(new String[cnamesList.size()]),
                 comment, enabled);
             returnControlToParentHandler();
         }
     }
 
-    public class ListDistributionListHandler extends SimpleHandler {
-        private List distributions = new ArrayList();
-        private List cnamesList = new ArrayList();
+    public class DistributionListHandler extends SimpleHandler {
+        private final List<Distribution> distributions = new ArrayList<Distribution>();
+        private final List<String> cnamesList = new ArrayList<String>();
         private String marker = null;
         private String nextMarker = null;
         private int maxItems = 100;
         private boolean isTruncated = false;
 
-        public List getDistributions() {
+        public DistributionListHandler(XMLReader xr) {
+            super(xr);
+        }
+
+        public List<Distribution> getDistributions() {
             return distributions;
         }
 
@@ -525,13 +522,14 @@ public class CloudFrontXmlResponsesSaxParser {
         }
 
         public void startDistributionSummary() {
-            transferControlToHandler(new DistributionSummaryHandler());
+            transferControlToHandler(new DistributionSummaryHandler(xr));
         }
 
         public void startStreamingDistributionSummary() {
-            transferControlToHandler(new DistributionSummaryHandler());
+            transferControlToHandler(new DistributionSummaryHandler(xr));
         }
 
+        @Override
         public void controlReturned(SimpleHandler childHandler) {
             distributions.add(
                 ((DistributionSummaryHandler) childHandler).getDistribution());
@@ -558,6 +556,51 @@ public class CloudFrontXmlResponsesSaxParser {
         }
     }
 
+    public class OriginHandler extends SimpleHandler {
+        protected Origin origin = null;
+        private String dnsName = "";
+        private String originAccessIdentity = null; // S3Origin
+        private String httpPort = null; // CustomOrigin
+        private String httpsPort = null; // CustomOrigin
+        private String originProtocolPolicy = null; // CustomOrigin
+
+        public OriginHandler(XMLReader xr) {
+            super(xr);
+        }
+
+        public void endDNSName(String text) {
+            this.dnsName = text;
+        }
+
+        public void endOriginAccessIdentity(String text) {
+            this.originAccessIdentity = text;
+        }
+
+        public void endHTTPPort(String text) {
+            this.httpPort = text;
+        }
+
+        public void endHTTPSPort(String text) {
+            this.httpsPort = text;
+        }
+
+        public void endOriginProtocolPolicy(String text) {
+            this.originProtocolPolicy = text;
+        }
+
+        public void endS3Origin(String text) {
+            this.origin = new S3Origin(this.dnsName, this.originAccessIdentity);
+            returnControlToParentHandler();
+        }
+
+        public void endCustomOrigin(String text) {
+            this.origin = new CustomOrigin(this.dnsName,
+                CustomOrigin.OriginProtocolPolicy.fromText(this.originProtocolPolicy),
+                Integer.valueOf(this.httpPort), Integer.valueOf(this.httpsPort));
+            returnControlToParentHandler();
+        }
+    }
+
     public class OriginAccessIdentityHandler extends SimpleHandler {
         private String id = null;
         private String s3CanonicalUserId = null;
@@ -565,26 +608,31 @@ public class CloudFrontXmlResponsesSaxParser {
         private OriginAccessIdentity originAccessIdentity = null;
         private OriginAccessIdentityConfig originAccessIdentityConfig = null;
 
-        public OriginAccessIdentity getOriginAccessIdentity() {
-    		return this.originAccessIdentity;
-    	}
+        public OriginAccessIdentityHandler(XMLReader xr) {
+            super(xr);
+        }
 
-    	public void endId(String text) {
-        	this.id = text;
+        public OriginAccessIdentity getOriginAccessIdentity() {
+            return this.originAccessIdentity;
+        }
+
+        public void endId(String text) {
+            this.id = text;
         }
 
         public void endS3CanonicalUserId(String text) {
-        	this.s3CanonicalUserId = text;
+            this.s3CanonicalUserId = text;
         }
 
         public void endComment(String text) {
-        	this.comment = text;
+            this.comment = text;
         }
 
         public void startCloudFrontOriginAccessIdentityConfig() {
-            transferControlToHandler(new OriginAccessIdentityConfigHandler());
+            transferControlToHandler(new OriginAccessIdentityConfigHandler(xr));
         }
 
+        @Override
         public void controlReturned(SimpleHandler childHandler) {
             this.originAccessIdentityConfig =
                 ((OriginAccessIdentityConfigHandler) childHandler).getOriginAccessIdentityConfig();
@@ -592,12 +640,12 @@ public class CloudFrontXmlResponsesSaxParser {
 
         public void endCloudFrontOriginAccessIdentity(String text) {
             this.originAccessIdentity = new OriginAccessIdentity(
-        		this.id, this.s3CanonicalUserId, this.originAccessIdentityConfig);
+                this.id, this.s3CanonicalUserId, this.originAccessIdentityConfig);
         }
 
         public void endCloudFrontOriginAccessIdentitySummary(String text) {
             this.originAccessIdentity = new OriginAccessIdentity(
-            		this.id, this.s3CanonicalUserId, this.comment);
+                    this.id, this.s3CanonicalUserId, this.comment);
             returnControlToParentHandler();
         }
     }
@@ -607,9 +655,13 @@ public class CloudFrontXmlResponsesSaxParser {
         private String comment = null;
         private OriginAccessIdentityConfig config = null;
 
+        public OriginAccessIdentityConfigHandler(XMLReader xr) {
+            super(xr);
+        }
+
         public OriginAccessIdentityConfig getOriginAccessIdentityConfig() {
-    		return this.config;
-    	}
+            return this.config;
+        }
 
         public void endCallerReference(String text) {
             this.callerReference = text;
@@ -626,13 +678,18 @@ public class CloudFrontXmlResponsesSaxParser {
     }
 
     public class OriginAccessIdentityListHandler extends SimpleHandler {
-        private List originAccessIdentityList = new ArrayList();
+        private final List<OriginAccessIdentity> originAccessIdentityList =
+            new ArrayList<OriginAccessIdentity>();
         private String marker = null;
         private String nextMarker = null;
         private int maxItems = 100;
         private boolean isTruncated = false;
 
-        public List getOriginAccessIdentityList() {
+        public OriginAccessIdentityListHandler(XMLReader xr) {
+            super(xr);
+        }
+
+        public List<OriginAccessIdentity> getOriginAccessIdentityList() {
             return this.originAccessIdentityList;
         }
 
@@ -653,9 +710,10 @@ public class CloudFrontXmlResponsesSaxParser {
         }
 
         public void startCloudFrontOriginAccessIdentitySummary() {
-            transferControlToHandler(new OriginAccessIdentityHandler());
+            transferControlToHandler(new OriginAccessIdentityHandler(xr));
         }
 
+        @Override
         public void controlReturned(SimpleHandler childHandler) {
             originAccessIdentityList.add(
                 ((OriginAccessIdentityHandler) childHandler).getOriginAccessIdentity());
@@ -678,6 +736,109 @@ public class CloudFrontXmlResponsesSaxParser {
         }
     }
 
+    public class InvalidationListHandler extends SimpleHandler {
+        private String marker = null;
+        private String nextMarker = null;
+        private int maxItems = 100;
+        private boolean isTruncated = false;
+        private String invalidationSummaryId = null;
+        private String invalidationSummaryStatus = null;
+        private List<InvalidationSummary> invalidationSummaries =
+            new ArrayList<InvalidationSummary>();
+        private InvalidationList invalidationList = null;
+
+        public InvalidationListHandler(XMLReader xr) {
+            super(xr);
+        }
+
+        public InvalidationList getInvalidationList() {
+            return invalidationList;
+        }
+
+        public boolean isTruncated() {
+            return isTruncated;
+        }
+
+        public String getMarker() {
+            return marker;
+        }
+
+        public String getNextMarker() {
+            return nextMarker;
+        }
+
+        public int getMaxItems() {
+            return maxItems;
+        }
+
+        public void endMarker(String text) {
+            this.marker = text;
+        }
+
+        public void endNextMarker(String text) {
+            this.nextMarker = text;
+        }
+
+        public void endMaxItems(String text) {
+            this.maxItems = Integer.parseInt(text);
+        }
+
+        public void endIsTruncated(String text) {
+            this.isTruncated = "true".equalsIgnoreCase(text);
+        }
+
+        // Inside InvalidationSummary
+        public void endId(String text) {
+            this.invalidationSummaryId = text;
+        }
+
+        // Inside InvalidationSummary
+        public void endStatus(String text) {
+            this.invalidationSummaryStatus = text;
+            this.invalidationSummaries.add(new InvalidationSummary(
+                this.invalidationSummaryId, this.invalidationSummaryStatus));
+        }
+
+        public void endInvalidationList(String ignore) {
+            this.invalidationList = new InvalidationList(
+                this.marker, this.nextMarker, this.maxItems, this.isTruncated,
+                this.invalidationSummaries);
+        }
+    }
+
+    public class InvalidationHandler extends SimpleHandler {
+        private Invalidation invalidation = new Invalidation();
+
+        public InvalidationHandler(XMLReader xr) {
+            super(xr);
+        }
+
+        public Invalidation getInvalidation() {
+            return this.invalidation;
+        }
+
+        public void endId(String text) {
+            this.invalidation.setId(text);
+        }
+
+        public void endStatus(String text) {
+            this.invalidation.setStatus(text);
+        }
+
+        public void endCreateTime(String text) throws ParseException {
+            this.invalidation.setCreateTime(
+                ServiceUtils.parseIso8601Date(text));
+        }
+
+        public void endPath(String text) {
+            this.invalidation.getObjectKeys().add(text.substring(1));
+        }
+
+        public void endCallerReference(String text) {
+            this.invalidation.setCallerReference(text);
+        }
+    }
+
     public class ErrorHandler extends SimpleHandler {
         private String type = null;
         private String code = null;
@@ -685,6 +846,10 @@ public class CloudFrontXmlResponsesSaxParser {
         private String detail = null;
         private String requestId = null;
 
+        public ErrorHandler(XMLReader xr) {
+            super(xr);
+        }
+
         public String getCode() {
             return code;
         }
