@@ -37,7 +37,7 @@ import org.jets3t.service.Jets3tProperties;
  * <p>
  * This class uses properties obtained through {@link Jets3tProperties}. For more information on
  * these properties please refer to
- * <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html">JetS3t Configuration</a>
+ * <a href="http://www.jets3t.org/toolkit/configuration.html">JetS3t Configuration</a>
  * </p>
  *
  * @author James Murty
@@ -59,8 +59,6 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
      * read, up to the buffer limit specified.
      * @param bufferSize
      * the number of bytes buffered by this class.
-     *
-     * @throws java.io.FileNotFoundException
      */
     public RepeatableInputStream(InputStream inputStream, int bufferSize) {
         if (inputStream == null) {
@@ -84,10 +82,11 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
      * when the available buffer size has been exceeded, in which case the input stream data cannot
      * be repeated.
      */
+    @Override
     public void reset() throws IOException {
         if (bytesReadPastMark <= bufferSize) {
             if (log.isDebugEnabled()) {
-            	log.debug("Reset after reading " + bytesReadPastMark + " bytes.");
+                log.debug("Reset after reading " + bytesReadPastMark + " bytes.");
             }
             bufferOffset = 0;
         } else {
@@ -97,6 +96,7 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
         }
     }
 
+    @Override
     public boolean markSupported() {
         return true;
     }
@@ -105,34 +105,38 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
      * This method can only be used while less data has been read from the input
      * stream than fits into the buffer. The readLimit parameter is ignored entirely.
      */
+    @Override
     public synchronized void mark(int readlimit) {
         if (log.isDebugEnabled()) {
-        	log.debug("Input stream marked at " + bytesReadPastMark + " bytes");
+            log.debug("Input stream marked at " + bytesReadPastMark + " bytes");
         }
         if (bytesReadPastMark <= bufferSize && buffer != null) {
             // Clear buffer of already-read data to make more space.
-        	// it is safe to cast bytesReadPastMark to an int because it is known to be less than bufferSize, which is an int
+            // it is safe to cast bytesReadPastMark to an int because it is known to be less than bufferSize, which is an int
             byte[] newBuffer = new byte[this.bufferSize];
-        	System.arraycopy(buffer, bufferOffset, newBuffer, 0, (int)(bytesReadPastMark - bufferOffset));
+            System.arraycopy(buffer, bufferOffset, newBuffer, 0, (int)(bytesReadPastMark - bufferOffset));
             this.buffer = newBuffer;
             this.bytesReadPastMark -= bufferOffset;
-        	this.bufferOffset = 0;
+            this.bufferOffset = 0;
         } else {
             // If mark is called after the buffer was already exceeded, create a new buffer.
-        	this.bufferOffset = 0;
+            this.bufferOffset = 0;
             this.bytesReadPastMark = 0;
             this.buffer = new byte[this.bufferSize];
         }
     }
 
+    @Override
     public int available() throws IOException {
         return is.available();
     }
 
+    @Override
     public void close() throws IOException {
         is.close();
     }
 
+    @Override
     public int read(byte[] out, int outOffset, int outLength) throws IOException {
         byte[] tmp = new byte[outLength];
 
@@ -164,7 +168,7 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
         } else if (buffer != null) {
             // We have exceeded the buffer capacity, after which point it is of no use. Free the memory.
             if (log.isDebugEnabled()) {
-            	log.debug("Buffer size " + bufferSize + " has been exceeded and the input stream "
+                log.debug("Buffer size " + bufferSize + " has been exceeded and the input stream "
                 + "will not be repeatable until the next mark. Freeing buffer memory");
             }
             buffer = null;
@@ -177,6 +181,7 @@ public class RepeatableInputStream extends InputStream implements InputStreamWra
         return count;
     }
 
+    @Override
     public int read() throws IOException {
         byte[] tmp = new byte[1];
         int count = read(tmp);
