@@ -18,29 +18,35 @@
  */
 package org.jets3t.service.model;
 
-import java.util.Date;
-
-import org.jets3t.service.acl.AccessControlList;
+import java.util.ArrayList;
+import java.util.List;
 
 /**
  * Represents an S3 bucket.
  *
  * @author James Murty
  */
-public class S3Bucket extends BaseS3Object {
-    private static final long serialVersionUID = -8646831898339939580L;
-
-    public static final String METADATA_HEADER_CREATION_DATE = "Date";
-    public static final String METADATA_HEADER_OWNER = "Owner";
-
+public class S3Bucket extends StorageBucket {
     public static final String LOCATION_US = null;
     public static final String LOCATION_US_STANDARD = null;
     public static final String LOCATION_US_WEST = "us-west-1";
     public static final String LOCATION_EUROPE = "EU";
-    public static final String LOCATION_ASIA_PACIFIC = "ap-southeast-1";
+    public static final String LOCATION_ASIA_PACIFIC_SOUTHEAST = "ap-southeast-1";
+    /**
+     * Alias of {@link #LOCATION_ASIA_PACIFIC_SOUTHEAST}
+     */
+    public static final String LOCATION_ASIA_PACIFIC = LOCATION_ASIA_PACIFIC_SOUTHEAST;
+    /**
+     * Alias of {@link #LOCATION_ASIA_PACIFIC_SOUTHEAST}
+     */
+    public static final String LOCATION_ASIA_PACIFIC_SINGAPORE = LOCATION_ASIA_PACIFIC_SOUTHEAST;
+    public static final String LOCATION_ASIA_PACIFIC_NORTHEAST = "ap-northeast-1";
+    /**
+     * Alias of {@link #LOCATION_ASIA_PACIFIC_NORTHEAST}
+     */
+    public static final String LOCATION_ASIA_PACIFIC_TOKYO = LOCATION_ASIA_PACIFIC_NORTHEAST;
+
 
-    private String name = null;
-    private AccessControlList acl = null;
     private String location = LOCATION_US;
     private boolean isLocationKnown = false;
     private boolean requesterPays = false;
@@ -50,6 +56,7 @@ public class S3Bucket extends BaseS3Object {
      * Create a bucket without any name or location specified
      */
     public S3Bucket() {
+        super();
     }
 
     /**
@@ -58,7 +65,7 @@ public class S3Bucket extends BaseS3Object {
      * @param name the name for the bucket
      */
     public S3Bucket(String name) {
-        this.name = name;
+        super(name);
     }
 
     /**
@@ -70,89 +77,19 @@ public class S3Bucket extends BaseS3Object {
      * {@link #LOCATION_EUROPE}.
      */
     public S3Bucket(String name, String location) {
-        this.name = name;
+        this(name);
         this.location = location;
         this.isLocationKnown = true;
     }
 
+    @Override
     public String toString() {
-    	return "S3Bucket [name=" + getName() +
+        return "S3Bucket [name=" + getName() +
             ",location=" + getLocation() +
             ",creationDate=" + getCreationDate() + ",owner=" + getOwner()
             + "] Metadata=" + getMetadataMap();
     }
 
-    /**
-     * @return
-     * the bucket's owner, or null if it is unknown.
-     */
-    public S3Owner getOwner() {
-    	return (S3Owner) getMetadata(METADATA_HEADER_OWNER);
-    }
-
-    /**
-     * Sets the bucket's owner in S3 - this should only be used internally by JetS3t
-     * methods that retrieve information directly from S3.
-     *
-     * @param owner
-     */
-    public void setOwner(S3Owner owner) {
-        addMetadata(METADATA_HEADER_OWNER, owner);
-    }
-
-    /**
-     * @return
-     * the bucket's creation date, or null if it is unknown.
-     */
-    public Date getCreationDate() {
-    	return (Date) getMetadata(METADATA_HEADER_CREATION_DATE);
-    }
-
-    /**
-     * Sets the bucket's creation date in S3 - this should only be used internally by JetS3t
-     * methods that retrieve information directly from S3.
-     *
-     * @param creationDate
-     */
-    public void setCreationDate(Date creationDate) {
-    	addMetadata(METADATA_HEADER_CREATION_DATE, creationDate);
-    }
-
-    /**
-     * @return
-     * the bucket's Access Control List, or null if it is unknown.
-     */
-    public AccessControlList getAcl() {
-    	return acl;
-    }
-
-    /**
-     * Sets the bucket's Access Control List in S3 - this should only be used internally by J3tS3t
-     * methods that retrieve information directly from S3.
-     *
-     * @param acl
-     */
-    public void setAcl(AccessControlList acl) {
-    	this.acl = acl;
-    }
-
-    /**
-     * @return
-     * the name of the bucket.
-     */
-    public String getName() {
-    	return name;
-    }
-
-    /**
-     * Set the name of the bucket. All buckets in S3 share a single namespace,
-     * so choose a unique name for your bucket.
-     * @param name the name for the bucket
-     */
-    public void setName(String name) {
-    	this.name = name;
-    }
-
     /**
      * Set's the bucket's location. This method should only be used internally by
      * JetS3t methods that retrieve information directly from S3.
@@ -225,4 +162,12 @@ public class S3Bucket extends BaseS3Object {
         return requesterPays;
     }
 
+    public static S3Bucket[] cast(StorageBucket[] buckets) {
+        List<S3Bucket> results = new ArrayList<S3Bucket>();
+        for (StorageBucket bucket: buckets) {
+            results.add((S3Bucket)bucket);
+        }
+        return results.toArray(new S3Bucket[results.size()]);
+    }
+
 }
