@@ -18,47 +18,22 @@
  */
 package org.jets3t.service.model;
 
-import java.io.Serializable;
 
 /**
  * Represents an S3 owner object with a canonical ID and, optionally, a display name.
  *
  * @author James Murty
  */
-public class S3Owner implements Serializable {
-    private static final long serialVersionUID = -8916731456944569115L;
+public class S3Owner extends StorageOwner {
 
-    private String displayName;
-    private String id;
+    private static final long serialVersionUID = 3895047011353549858L;
 
     public S3Owner() {
+        super();
     }
 
     public S3Owner(String id, String displayName) {
-        this.id = id;
-        this.displayName = displayName;
-    }
-
-    public String toString() {
-    	return "S3Owner ["
-    		+ (getDisplayName() != null ? "name=" + getDisplayName() + ", " : "")
-    		+ "id=" + getId() + "]";
-    }
-
-    public String getId() {
-    	return id;
-    }
-
-    public void setId(String id) {
-    	this.id = id;
-    }
-
-    public String getDisplayName() {
-    	return displayName;
-    }
-
-    public void setDisplayName(String name) {
-    	this.displayName = name;
+        super(id, displayName);
     }
 
 }
