@@ -22,10 +22,7 @@ import java.util.Arrays;
 
 
 public class DistributionConfig {
-    public static final String ORIGIN_ACCESS_IDENTITY_PREFIX =
-    	"origin-access-identity/cloudfront/";
-
-    private String origin = null;
+    private Origin origin = null;
     private String callerReference = null;
     private String[] cnames = new String[0];
     private String comment = null;
@@ -33,16 +30,16 @@ public class DistributionConfig {
     private String etag = null;
     private LoggingStatus loggingStatus = null;
     // Private distribution settings
-    private String originAccessIdentity = null;
     private boolean trustedSignerSelf = false;
     private String[] trustedSignerAwsAccountNumbers = new String[0];
     private String[] requiredProtocols = new String[0];
+    private String defaultRootObject = null;
 
-    public DistributionConfig(String origin, String callerReference,
+    public DistributionConfig(Origin origin, String callerReference,
         String[] cnames, String comment, boolean enabled,
-        LoggingStatus loggingStatus, String originAccessIdentity,
-        boolean trustedSignerSelf, String[] trustedSignerAwsAccountNumbers,
-        String[] requiredProtocols)
+        LoggingStatus loggingStatus, boolean trustedSignerSelf,
+        String[] trustedSignerAwsAccountNumbers,
+        String[] requiredProtocols, String defaultRootObject)
     {
         this.origin = origin;
         this.callerReference = callerReference;
@@ -50,27 +47,21 @@ public class DistributionConfig {
         this.comment = comment;
         this.enabled = enabled;
         this.loggingStatus = loggingStatus;
-        // Ensure origin access identity has required prefix
-        if (originAccessIdentity != null
-        	&& !originAccessIdentity.startsWith(ORIGIN_ACCESS_IDENTITY_PREFIX))
-        {
-            originAccessIdentity = ORIGIN_ACCESS_IDENTITY_PREFIX + originAccessIdentity;
-        }
-        this.originAccessIdentity = originAccessIdentity;
         this.trustedSignerSelf = trustedSignerSelf;
         this.trustedSignerAwsAccountNumbers = trustedSignerAwsAccountNumbers;
         this.requiredProtocols = requiredProtocols;
+        this.defaultRootObject = defaultRootObject;
     }
 
-    public DistributionConfig(String origin, String callerReference,
+    public DistributionConfig(Origin origin, String callerReference,
             String[] cnames, String comment, boolean enabled,
             LoggingStatus loggingStatus)
     {
         this(origin, callerReference, cnames, comment, enabled,
-        		loggingStatus, null, false, null, null);
+                loggingStatus, false, null, null, null);
     }
 
-    public String getOrigin() {
+    public Origin getOrigin() {
         return origin;
     }
 
@@ -106,12 +97,9 @@ public class DistributionConfig {
         return this.loggingStatus != null;
     }
 
-    public String getOriginAccessIdentity() {
-        return this.originAccessIdentity;
-    }
-
     public boolean isPrivate() {
-        return this.originAccessIdentity != null;
+        return (this.getOrigin() instanceof S3Origin
+            && ((S3Origin)this.getOrigin()).getOriginAccessIdentity() != null);
     }
 
     public String[] getTrustedSignerAwsAccountNumbers() {
@@ -124,7 +112,7 @@ public class DistributionConfig {
 
     public boolean hasTrustedSignerAwsAccountNumbers() {
         return getTrustedSignerAwsAccountNumbers() != null
-    		&& getTrustedSignerAwsAccountNumbers().length > 0;
+            && getTrustedSignerAwsAccountNumbers().length > 0;
     }
 
     public boolean isUrlSigningRequired() {
@@ -158,33 +146,39 @@ public class DistributionConfig {
         }
     }
 
+    public String getDefaultRootObject() {
+        return defaultRootObject;
+    }
+
+    @Override
     public String toString() {
         return
             (isStreamingDistributionConfig()
-            	? "StreamingDistributionConfig"
-    			: "DistributionConfig")
+                ? "StreamingDistributionConfig"
+                : "DistributionConfig")
             + ": origin=" + origin
             + ", callerReference=" + callerReference + ", comment=" + comment
             + ", enabled=" + enabled +
             (isPrivate()
-            	? ", Private:originAccessIdentity=" + originAccessIdentity
-    			: ", Public") +
+                ? ", Private:originAccessIdentity=" + ((S3Origin)getOrigin()).getOriginAccessIdentity()
+                : ", Public") +
             (isUrlSigningRequired()
-                	? ", TrustedSigners:self=" + isTrustedSignerSelf()
-            			+ (hasTrustedSignerAwsAccountNumbers()
-        					? ":awsAccountNumbers="
-    							+ Arrays.asList(getTrustedSignerAwsAccountNumbers())
-    						: "")
-        			: "") +
+                    ? ", TrustedSigners:self=" + isTrustedSignerSelf()
+                        + (hasTrustedSignerAwsAccountNumbers()
+                            ? ":awsAccountNumbers="
+                                + Arrays.asList(getTrustedSignerAwsAccountNumbers())
+                            : "")
+                    : "") +
             (etag != null ? ", etag=" + etag : "") +
             (!isLoggingEnabled()
-            	? 	""
-                : 	", LoggingStatus: bucket=" + loggingStatus.getBucket() +
-                	", prefix=" + loggingStatus.getPrefix()) +
+                ?     ""
+                :     ", LoggingStatus: bucket=" + loggingStatus.getBucket() +
+                    ", prefix=" + loggingStatus.getPrefix()) +
             (getRequiredProtocols() == null || getRequiredProtocols().length == 0
                 ? ""
                 : ", RequiredProtocols=" + Arrays.asList(getRequiredProtocols())) +
-            ", CNAMEs=" + Arrays.asList(cnames);
+            ", CNAMEs=" + Arrays.asList(cnames) +
+                ", DefaultRootObject=" + defaultRootObject;
     }
 
 }
