@@ -18,23 +18,13 @@
  */
 package org.jets3t.service.multithread;
 
-import java.io.Serializable;
-import java.util.EventListener;
-
 /**
  * Interface implemented by multi-threaded S3 operations that can be cancelled prior to finishing.
  *
  * @author James Murty
+ *
+ * @deprecated 0.8.0 use {@link org.jets3t.service.multi.CancelEventTrigger} instead.
  */
-public interface CancelEventTrigger extends EventListener, Serializable {
-
-    /**
-     * Triggers a cancellation of some operation.
-     *
-     * @param eventSource
-     * the object source that triggered the cancellation, useful for logging purposes.
-     *
-     */
-    public abstract void cancelTask(Object eventSource);
-
+@Deprecated
+public interface CancelEventTrigger extends org.jets3t.service.multi.CancelEventTrigger {
 }
