@@ -2,7 +2,7 @@
  * JetS3t : Java S3 Toolkit
  * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty, 2008 Zmanda Inc.
+ * Copyright 2006-2010 James Murty, 2008 Zmanda Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,17 +38,27 @@ public class AWSDevPayCredentials extends AWSCredentials {
         super(awsAccessKey, awsSecretAccessKey, friendlyName);
     }
 
+    @Override
+    protected String getTypeName() {
+        return "devpay";
+    }
+
+    @Override
+    public String getVersionPrefix() {
+        return "jets3t AWS Credentials, version: ";
+    }
+
     /**
      * Construct credentials.
      *
      * @param awsAccessKey
      * AWS access key for an Amazon S3 account.
      * @param awsSecretAccessKey
-     * AWS secret key for an Amazon S3 acount.
+     * AWS secret key for an Amazon S3 account.
      * @param awsUserToken
-     * DevPay user token for an Amazon S3 acount.
+     * DevPay user token for an Amazon S3 account.
      * @param awsProductToken
-     * DevPay product token for an Amazon S3 acount.
+     * DevPay product token for an Amazon S3 account.
      */
     public AWSDevPayCredentials(String awsAccessKey, String awsSecretAccessKey, String awsUserToken, String awsProductToken) {
         super(awsAccessKey, awsSecretAccessKey);
@@ -62,11 +72,11 @@ public class AWSDevPayCredentials extends AWSCredentials {
      * @param awsAccessKey
      * AWS access key for an Amazon S3 account.
      * @param awsSecretAccessKey
-     * AWS secret key for an Amazon S3 acount.
+     * AWS secret key for an Amazon S3 account.
      * @param awsUserToken
-     * DevPay user token for an Amazon S3 acount.
+     * DevPay user token for an Amazon S3 account.
      * @param awsProductToken
-     * DevPay product token for an Amazon S3 acount.
+     * DevPay product token for an Amazon S3 account.
      * @param friendlyName
      * a name identifying the owner of the credentials, such as 'James'.
      */
@@ -96,22 +106,16 @@ public class AWSDevPayCredentials extends AWSCredentials {
      * @return
      * a string summarizing these credentials
      */
+    @Override
     public String getLogString() {
         return super.getLogString() + " : " + getUserToken() + " : " + getProductToken();
     }
 
-    /**
-     * @return
-     * string representing this credential type's name (for serialization)
-     */
-    protected String getTypeName() {
-        return DEVPAY_TYPE_NAME;
-    }
-
     /**
      * @return
      * the string of data that needs to be encrypted (for serialization)
      */
+    @Override
     protected String getDataToEncrypt() {
         return getAccessKey() + V3_KEYS_DELIMITER +
             getSecretKey() + V3_KEYS_DELIMITER +
