@@ -24,6 +24,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.util.HashMap;
+import java.util.Map;
 import java.util.StringTokenizer;
 
 import org.apache.commons.logging.Log;
@@ -44,7 +45,7 @@ import org.apache.commons.logging.LogFactory;
  * considered comments. Lines that have a mimetype but no associated extensions are also ignored.
  * <p>
  * For more information about Mimetype settings please see:
- * <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html">JetS3t Configuration</a>
+ * <a href="http://www.jets3t.org/toolkit/configuration.html">JetS3t Configuration</a>
  *
  * @author James Murty
  */
@@ -64,6 +65,10 @@ public class Mimetypes {
      * The default binary mimetype: application/octet-stream
      */
     public static final String MIMETYPE_OCTET_STREAM = "application/octet-stream";
+    /**
+     * A binary mimetype: binary/octet-stream
+     */
+    public static final String MIMETYPE_BINARY_OCTET_STREAM = "binary/octet-stream";
     /**
      * The default gzip mimetype: application/x-gzip
      */
@@ -73,7 +78,9 @@ public class Mimetypes {
     /**
      * A JetS3t-specific mimetype used to indicate that an S3 object actually represents
      * a directory on the local file system.
+     * @deprecated 0.8.0
      */
+    @Deprecated
     public static final String MIMETYPE_JETS3T_DIRECTORY = "application/x-directory";
 
     private static Mimetypes mimetypes = null;
@@ -81,7 +88,7 @@ public class Mimetypes {
     /**
      * Map that stores file extensions as keys, and the corresponding mimetype as values.
      */
-    private HashMap extensionToMimetypeMap = new HashMap();
+    private final Map<String, String> extensionToMimetypeMap = new HashMap<String, String>();
 
     private Mimetypes() {
     }
@@ -97,18 +104,18 @@ public class Mimetypes {
         InputStream mimetypesFile = mimetypes.getClass().getResourceAsStream("/mime.types");
         if (mimetypesFile != null) {
             if (log.isDebugEnabled()) {
-            	log.debug("Loading mime types from file in the classpath: mime.types");
+                log.debug("Loading mime types from file in the classpath: mime.types");
             }
             try {
                 mimetypes.loadAndReplaceMimetypes(mimetypesFile);
             } catch (IOException e) {
                 if (log.isErrorEnabled()) {
-                	log.error("Failed to load mime types from file in the classpath: mime.types", e);
+                    log.error("Failed to load mime types from file in the classpath: mime.types", e);
                 }
             }
         } else {
             if (log.isWarnEnabled()) {
-            	log.warn("Unable to find 'mime.types' file in classpath");
+                log.warn("Unable to find 'mime.types' file in classpath");
             }
         }
         return mimetypes;
@@ -145,7 +152,7 @@ public class Mimetypes {
                     }
                 } else {
                     if (log.isDebugEnabled()) {
-                    	log.debug("Ignoring mimetype with no associated file extensions: '" + line + "'");
+                        log.debug("Ignoring mimetype with no associated file extensions: '" + line + "'");
                     }
                 }
             }
@@ -174,20 +181,20 @@ public class Mimetypes {
         if (lastPeriodIndex > 0 && lastPeriodIndex + 1 < fileName.length()) {
             String ext = fileName.substring(lastPeriodIndex + 1);
             if (extensionToMimetypeMap.keySet().contains(ext)) {
-                String mimetype = (String) extensionToMimetypeMap.get(ext);
+                String mimetype = extensionToMimetypeMap.get(ext);
                 if (log.isDebugEnabled()) {
                     log.debug("Recognised extension '" + ext + "', mimetype is: '" + mimetype + "'");
                 }
                 return mimetype;
             } else {
                 if (log.isDebugEnabled()) {
-                	log.debug("Extension '" + ext + "' is unrecognized in mime type listing"
+                    log.debug("Extension '" + ext + "' is unrecognized in mime type listing"
                     + ", using default mime type: '" + MIMETYPE_OCTET_STREAM + "'");
                 }
             }
         } else {
             if (log.isDebugEnabled()) {
-            	log.debug("File name has no extension, mime type cannot be recognised for: " + fileName);
+                log.debug("File name has no extension, mime type cannot be recognised for: " + fileName);
             }
         }
         return MIMETYPE_OCTET_STREAM;
