@@ -30,14 +30,15 @@ import java.util.Date;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.jets3t.service.Constants;
-import org.jets3t.service.S3ServiceException;
+import org.jets3t.service.ServiceException;
 import org.jets3t.service.acl.AccessControlList;
 import org.jets3t.service.io.BytesProgressWatcher;
 import org.jets3t.service.io.GZipDeflatingInputStream;
 import org.jets3t.service.io.ProgressMonitoredInputStream;
 import org.jets3t.service.io.TempFile;
 import org.jets3t.service.model.S3Object;
-import org.jets3t.service.multithread.DownloadPackage;
+import org.jets3t.service.model.StorageObject;
+import org.jets3t.service.multi.DownloadPackage;
 import org.jets3t.service.security.EncryptionUtil;
 
 /**
@@ -56,14 +57,14 @@ public class ObjectUtils {
      * <p>
      * The file will have the following metadata items added:
      * <ul>
-     * <li><i>Constants.METADATA_JETS3T_LOCAL_FILE_DATE</i> : The local file's last modified date
+     * <li>{@link Constants#METADATA_JETS3T_LOCAL_FILE_DATE}: The local file's last modified date
      *     in ISO 8601 format</li>
      * <li><tt>Content-Type</tt> : A content type guessed from the file's extension, or
-     *     </i>Mimetypes.MIMETYPE_JETS3T_DIRECTORY</i> if the file is a directory</li>
+     *     {@link Mimetypes#MIMETYPE_BINARY_OCTET_STREAM} if the file is a directory</li>
      * <li><tt>Content-Length</tt> : The size of the file</li>
      * <li><tt>MD5-Hash</tt> : An MD5 hash of the file's data</li>
-     * <li><i>S3Object.METADATA_HEADER_ORIGINAL_HASH_MD5</i> : An MD5 hash of the original file's
-     *     data (added if gzipping or encryption is applied)</li>
+     * <li>{@link StorageObject#METADATA_HEADER_ORIGINAL_HASH_MD5}: An MD5 hash of the
+     *     original file's data (added if gzipping or encryption is applied)</li>
      * </ul>
      *
      * @param objectKey
@@ -86,7 +87,8 @@ public class ObjectUtils {
      * exceptions could include IO failures, gzipping and encryption failures.
      */
     public static S3Object createObjectForUpload(String objectKey, File dataFile,
-        EncryptionUtil encryptionUtil, boolean gzipFile, BytesProgressWatcher progressWatcher) throws Exception
+        EncryptionUtil encryptionUtil, boolean gzipFile, BytesProgressWatcher progressWatcher)
+        throws Exception
     {
         S3Object s3Object = new S3Object(objectKey);
 
@@ -98,7 +100,7 @@ public class ObjectUtils {
 
         if (dataFile.isDirectory()) {
             s3Object.setContentLength(0);
-            s3Object.setContentType(Mimetypes.MIMETYPE_JETS3T_DIRECTORY);
+            s3Object.setContentType(Mimetypes.MIMETYPE_BINARY_OCTET_STREAM);
         } else {
             s3Object.setContentType(Mimetypes.getInstance().getMimetype(dataFile));
             File uploadFile = transformUploadFile(dataFile, s3Object, encryptionUtil,
@@ -135,13 +137,13 @@ public class ObjectUtils {
      * <p>
      * The file will have the following metadata items added:
      * <ul>
-     * <li><i>Constants.METADATA_JETS3T_LOCAL_FILE_DATE</i> : The local file's last modified date
+     * <li>{@link Constants#METADATA_JETS3T_LOCAL_FILE_DATE}: The local file's last modified date
      *     in ISO 8601 format</li>
      * <li><tt>Content-Type</tt> : A content type guessed from the file's extension, or
-     *     </i>Mimetypes.MIMETYPE_JETS3T_DIRECTORY</i> if the file is a directory</li>
+     *     {@link Mimetypes#MIMETYPE_BINARY_OCTET_STREAM} if the file is a directory</li>
      * <li><tt>Content-Length</tt> : The size of the file</li>
      * <li><tt>MD5-Hash</tt> : An MD5 hash of the file's data</li>
-     * <li><i>S3Object.METADATA_HEADER_ORIGINAL_HASH_MD5</i> : An MD5 hash of the original file's
+     * <li>{@link StorageObject#METADATA_HEADER_ORIGINAL_HASH_MD5}: An MD5 hash of the original file's
      *     data (added if gzipping or encryption is applied)</li>
      * </ul>
      *
@@ -272,7 +274,7 @@ public class ObjectUtils {
      * appropriate options are set.
      *
      * @param object
-     * the object in S3
+     * the object
      * @param fileTarget
      * the file to which downloaded (and possibly transformed) data will be written.
      * @param automaticUnzip
@@ -287,12 +289,14 @@ public class ObjectUtils {
      * a download package representing an S3Object and a taret file for the object's data.
      * @throws Exception
      */
-    public static DownloadPackage createPackageForDownload(S3Object object, File fileTarget,
+    public static DownloadPackage createPackageForDownload(StorageObject object, File fileTarget,
         boolean automaticUnzip, boolean automaticDecrypt, String encryptionPassword) throws Exception
     {
-        if (Mimetypes.MIMETYPE_JETS3T_DIRECTORY.equals(object.getContentType())) {
+        // Recognize directory place-holder objects and ignore them
+        if (object.isDirectoryPlaceholder()) {
             return null;
-        } else {
+        }
+        else {
             boolean isZipped = false;
             EncryptionUtil encryptionUtil = null;
 
@@ -308,7 +312,7 @@ public class ObjectUtils {
             {
                 // Object is encrypted.
                 if (encryptionPassword == null) {
-                    throw new S3ServiceException(
+                    throw new ServiceException(
                         "One or more objects are encrypted, and cannot be downloaded unless "
                         + " the encyption password is provided");
                 }
@@ -327,4 +331,87 @@ public class ObjectUtils {
         }
     }
 
+    /**
+     * Creates a download package representing an S3Object that will be downloaded, and the
+     * target file the downloaded data will be written to.
+     * <p>
+     * Downloaded data may be transformed if the S3Object is encrypted or gzipped and the
+     * appropriate options are set.
+     *
+     * @param object
+     * the object
+     * @param fileTarget
+     * the file to which downloaded (and possibly transformed) data will be written.
+     * @param automaticUnzip
+     * if true, gzipped objects will be decrypted on-the-fly as they are downloaded.
+     * @param automaticDecrypt
+     * if true, encrypted files will be decrypted on-the-fly as they are downloaded (in which
+     * case the encryptionPassword must be correct)
+     * @param encryptionPassword
+     * the password required to decrypt encrypted objects.
+     *
+     * @deprecated 0.8.0 use
+     * {@link #createPackageForDownload(StorageObject, File, boolean, boolean, String)} instead.
+     *
+     * @return
+     * a download package representing an S3Object and a taret file for the object's data.
+     * @throws Exception
+     */
+    @Deprecated
+    public static org.jets3t.service.multithread.DownloadPackage createPackageForDownload(
+        S3Object object, File fileTarget, boolean automaticUnzip, boolean automaticDecrypt,
+        String encryptionPassword) throws Exception
+    {
+        // Recognize directory place-holder objects and ignore them
+        if (object.isDirectoryPlaceholder()) {
+            return null;
+        }
+        else {
+            boolean isZipped = false;
+            EncryptionUtil encryptionUtil = null;
+
+            if (automaticUnzip &&
+                ("gzip".equalsIgnoreCase(object.getContentEncoding())
+                || object.containsMetadata(Constants.METADATA_JETS3T_COMPRESSED)))
+            {
+                // Object data is gzipped.
+                isZipped = true;
+            }
+            if (automaticDecrypt
+                && object.containsMetadata(Constants.METADATA_JETS3T_CRYPTO_ALGORITHM))
+            {
+                // Object is encrypted.
+                if (encryptionPassword == null) {
+                    throw new ServiceException(
+                        "One or more objects are encrypted, and cannot be downloaded unless "
+                        + " the encyption password is provided");
+                }
+
+                String algorithm = (String) object.getMetadata(
+                    Constants.METADATA_JETS3T_CRYPTO_ALGORITHM);
+                String version = (String) object.getMetadata(
+                    Constants.METADATA_JETS3T_CRYPTO_VERSION);
+                if (version == null) {
+                    version = EncryptionUtil.DEFAULT_VERSION;
+                }
+                encryptionUtil = new EncryptionUtil(encryptionPassword, algorithm, version);
+            }
+
+            return new org.jets3t.service.multithread.DownloadPackage(
+                object, fileTarget, isZipped, encryptionUtil);
+        }
+    }
+
+    public static String convertDirPlaceholderKeyNameToDirName(String objectKey) {
+        String dirPlaceholderKey = objectKey;
+        if (dirPlaceholderKey.endsWith("_$folder$")) {
+            int suffixPos = dirPlaceholderKey.indexOf("_$");
+            dirPlaceholderKey = dirPlaceholderKey.substring(0, suffixPos);
+        }
+        if (!dirPlaceholderKey.endsWith(Constants.FILE_PATH_DELIM)) {
+            dirPlaceholderKey = dirPlaceholderKey + Constants.FILE_PATH_DELIM;
+        }
+        return dirPlaceholderKey;
+    }
+
 }
