@@ -21,18 +21,16 @@ package org.jets3t.service.utils;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.net.URL;
+import java.net.URLDecoder;
 import java.net.URLEncoder;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.SortedMap;
 import java.util.TreeMap;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
 import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
 import org.apache.commons.httpclient.Header;
@@ -55,7 +53,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.jets3t.service.Constants;
 import org.jets3t.service.Jets3tProperties;
-import org.jets3t.service.S3ServiceException;
+import org.jets3t.service.ServiceException;
 import org.jets3t.service.impl.rest.httpclient.AWSRequestAuthorizer;
 import org.jets3t.service.impl.rest.httpclient.HttpClientAndConnectionManager;
 import org.jets3t.service.impl.rest.httpclient.RestS3Service;
@@ -88,7 +86,7 @@ public class RestUtils {
      * <tr><td>content-encoding</td></tr>
      * </table>
      */
-    public static final List HTTP_HEADER_METADATA_NAMES = Arrays.asList(new String[] {
+    public static final List<String> HTTP_HEADER_METADATA_NAMES = Arrays.asList(new String[] {
         "content-type",
         "content-md5",
         "content-length",
@@ -107,9 +105,9 @@ public class RestUtils {
      * @param path
      * @return
      * encoded URL.
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public static String encodeUrlString(String path) throws S3ServiceException {
+    public static String encodeUrlString(String path) throws ServiceException {
         try {
             String encodedPath = URLEncoder.encode(path, Constants.DEFAULT_ENCODING);
             // Web browsers do not always handle '+' characters well, use the well-supported '%20' instead.
@@ -118,7 +116,7 @@ public class RestUtils {
             encodedPath = encodedPath.replaceAll("%40", "@");
             return encodedPath;
         } catch (UnsupportedEncodingException uee) {
-            throw new S3ServiceException("Unable to encode path: " + path, uee);
+            throw new ServiceException("Unable to encode path: " + path, uee);
         }
     }
 
@@ -130,9 +128,9 @@ public class RestUtils {
      * @param delimiter
      * @return
      * encoded URL string.
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public static String encodeUrlPath(String path, String delimiter) throws S3ServiceException {
+    public static String encodeUrlPath(String path, String delimiter) throws ServiceException {
         StringBuffer result = new StringBuffer();
         String tokens[] = path.split(delimiter);
         for (int i = 0; i < tokens.length; i++) {
@@ -145,31 +143,34 @@ public class RestUtils {
     }
 
     /**
-     * Calculate the canonical string for a REST/HTTP request to S3.
+     * Calculate the canonical string for a REST/HTTP request to a storage service.
      *
      * When expires is non-null, it will be used instead of the Date header.
+     * @throws UnsupportedEncodingException
      */
-    public static String makeS3CanonicalString(String method, String resource, Map headersMap, String expires)
+    public static String makeServiceCanonicalString(String method, String resource,
+        Map<String, Object> headersMap, String expires, String headerPrefix,
+        List<String> serviceResourceParameterNames) throws UnsupportedEncodingException
     {
-        StringBuffer buf = new StringBuffer();
-        buf.append(method + "\n");
+        StringBuffer canonicalStringBuf = new StringBuffer();
+        canonicalStringBuf.append(method + "\n");
 
         // Add all interesting headers to a list, then sort them.  "Interesting"
         // is defined as Content-MD5, Content-Type, Date, and x-amz-
-        SortedMap interestingHeaders = new TreeMap();
+        SortedMap<String, Object> interestingHeaders = new TreeMap<String, Object>();
         if (headersMap != null && headersMap.size() > 0) {
-            Iterator headerIter = headersMap.entrySet().iterator();
-            while (headerIter.hasNext()) {
-                Map.Entry entry = (Map.Entry) headerIter.next();
+            for (Map.Entry<String, Object> entry: headersMap.entrySet()) {
                 Object key = entry.getKey();
                 Object value = entry.getValue();
 
-                if (key == null) continue;
+                if (key == null) {
+                    continue;
+                }
                 String lk = key.toString().toLowerCase(Locale.getDefault());
 
                 // Ignore any headers that are not particularly interesting.
                 if (lk.equals("content-type") || lk.equals("content-md5") || lk.equals("date") ||
-                    lk.startsWith(Constants.REST_HEADER_PREFIX))
+                    lk.startsWith(headerPrefix))
                 {
                     interestingHeaders.put(lk, value);
                 }
@@ -196,93 +197,66 @@ public class RestUtils {
             interestingHeaders.put("content-md5", "");
         }
 
-        // Finally, add all the interesting headers (i.e.: all that startwith x-amz- ;-))
-        for (Iterator i = interestingHeaders.entrySet().iterator(); i.hasNext(); ) {
-            Map.Entry entry = (Map.Entry) i.next();
-            String key = (String) entry.getKey();
+        // Finally, add all the interesting headers (i.e.: all that start with x-amz- ;-))
+        for (Map.Entry<String, Object> entry: interestingHeaders.entrySet()) {
+            String key = entry.getKey();
             Object value = entry.getValue();
 
-            if (key.startsWith(Constants.REST_HEADER_PREFIX)) {
-                buf.append(key).append(':').append(value);
+            if (key.startsWith(headerPrefix)) {
+                canonicalStringBuf.append(key).append(':').append(value);
             } else {
-                buf.append(value);
+                canonicalStringBuf.append(value);
             }
-            buf.append("\n");
+            canonicalStringBuf.append("\n");
         }
 
         // don't include the query parameters...
         int queryIndex = resource.indexOf('?');
         if (queryIndex == -1) {
-            buf.append(resource);
+            canonicalStringBuf.append(resource);
         } else {
-            buf.append(resource.substring(0, queryIndex));
+            canonicalStringBuf.append(resource.substring(0, queryIndex));
         }
 
-        // ...unless parameter is one of: acl, torrent, logging, requestPayment,
-        // versions, versioning, versionId.
-        boolean existingParams = false;
-        if (resource.matches(".*[&?]acl($|=|&).*")) {
-            buf.append("?acl");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]torrent($|=|&).*")) {
-            buf.append("?torrent");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]logging($|=|&).*")) {
-            buf.append("?logging");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]location($|=|&).*")) {
-            buf.append("?location");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]requestPayment($|=|&).*")) {
-            buf.append("?requestPayment");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]versions($|=|&).*")) {
-            buf.append("?versions");
-            existingParams = true;
-        } else if (resource.matches(".*[&?]versioning($|=|&).*")) {
-            buf.append("?versioning");
-            existingParams = true;
-        }
-        if (resource.matches(".*[&?](versionId=.+)($|&).*")) {
-            Pattern pattern = Pattern.compile(".*[&?](versionId=.+)($|&).*");
-            Matcher matcher = pattern.matcher(resource);
-            if (matcher.matches()) {
-                buf.append( (existingParams ? "&" : "?") + matcher.group(1));
-            }
-        }
+        // ...unless the parameter(s) are in the set of special params
+        // that actually identify a service resource.
+        if (queryIndex >= 0) {
+            SortedMap<String, String> sortedResourceParams = new TreeMap<String, String>();
 
-        return buf.toString();
-    }
-
-    /**
-     * Renames metadata property names to be suitable for use as HTTP Headers. This is done
-     * by renaming any non-HTTP headers to have the prefix <code>x-amz-meta-</code> and leaving the
-     * HTTP header names unchanged. The HTTP header names left unchanged are those found in
-     * {@link #HTTP_HEADER_METADATA_NAMES}
-     *
-     * @param metadata
-     * @return
-     * a map of metadata property name/value pairs renamed to be suitable for use as HTTP headers.
-     */
-    public static Map renameMetadataKeys(Map metadata) {
-        Map convertedMetadata = new HashMap();
-        // Add all meta-data headers.
-        if (metadata != null) {
-            Iterator metaDataIter = metadata.entrySet().iterator();
-            while (metaDataIter.hasNext()) {
-                Map.Entry entry = (Map.Entry) metaDataIter.next();
-                String key = (String) entry.getKey();
-                Object value = entry.getValue();
-
-                if (!HTTP_HEADER_METADATA_NAMES.contains(key.toLowerCase(Locale.getDefault()))
-                    && !key.startsWith(Constants.REST_HEADER_PREFIX))
-                {
-                    key = Constants.REST_METADATA_PREFIX + key;
+            // Parse parameters from resource string
+            String query = resource.substring(queryIndex + 1);
+            for (String paramPair: query.split("&")) {
+                String[] paramNameValue = paramPair.split("=");
+                String name = URLDecoder.decode(paramNameValue[0], "UTF-8");
+                String value = null;
+                if (paramNameValue.length > 1) {
+                    value = URLDecoder.decode(paramNameValue[1], "UTF-8");
                 }
-                convertedMetadata.put(key, value);
+                // Only include parameter (and its value if present) in canonical
+                // string if it is a resource-identifying parameter
+                if (serviceResourceParameterNames.contains(name)) {
+                    sortedResourceParams.put(name, value);
+                }
+            }
+
+            // Add resource parameters
+            if (sortedResourceParams.size() > 0) {
+                canonicalStringBuf.append("?");
+            }
+            boolean addedParam = false;
+            for (Map.Entry<String, String> entry: sortedResourceParams.entrySet()) {
+                if (addedParam) {
+                    canonicalStringBuf.append("&");
+                }
+                canonicalStringBuf.append(entry.getKey());
+                if (entry.getValue() != null) {
+                    canonicalStringBuf.append("=" + entry.getValue());
+                }
+                addedParam = true;
             }
         }
-        return convertedMetadata;
+
+        return canonicalStringBuf.toString();
     }
 
     /**
@@ -322,7 +296,7 @@ public class RestUtils {
         }
 
         connectionParams.setMaxConnectionsPerHost(
-        	HostConfiguration.ANY_HOST_CONFIGURATION, maxConnectionsPerHost);
+            HostConfiguration.ANY_HOST_CONFIGURATION, maxConnectionsPerHost);
         connectionParams.setMaxTotalConnections(maxConnections);
 
         // Connection properties to take advantage of S3 window scaling.
@@ -358,6 +332,7 @@ public class RestUtils {
         final int retryMaxCount = jets3tProperties.getIntProperty("httpclient.retry-max", 5);
 
         clientParams.setParameter(HttpClientParams.RETRY_HANDLER, new DefaultHttpMethodRetryHandler(retryMaxCount, false) {
+            @Override
             public boolean retryMethod(HttpMethod httpMethod, IOException ioe, int executionCount) {
                 if (super.retryMethod(httpMethod, ioe, executionCount)) {
                     if  (ioe instanceof UnrecoverableIOException) {
@@ -390,7 +365,7 @@ public class RestUtils {
         });
 
         long connectionManagerTimeout = jets3tProperties.getLongProperty(
-        	"httpclient.connection-manager-timeout", 0);
+            "httpclient.connection-manager-timeout", 0);
         clientParams.setConnectionManagerTimeout(connectionManagerTimeout);
 
         HttpClient httpClient = new HttpClient(clientParams, connectionManager);
@@ -416,6 +391,14 @@ public class RestUtils {
         initHttpProxy(httpClient, jets3tProperties, true, null, -1, null, null, null);
     }
 
+    /**
+     * Initialises this service's HTTP proxy by auto-detecting the proxy settings using the given endpoint.
+     */
+    public static void initHttpProxy(HttpClient httpClient, Jets3tProperties jets3tProperties,
+        String endpoint) {
+        initHttpProxy(httpClient, jets3tProperties, true, null, -1, null, null, null, endpoint);
+    }
+
     /**
      * Initialises this service's HTTP proxy with the given proxy settings.
      *
@@ -458,10 +441,31 @@ public class RestUtils {
      * @param proxyPassword
      * @param proxyDomain
      */
-    protected static void initHttpProxy(HttpClient httpClient,
+    public static void initHttpProxy(HttpClient httpClient,
         Jets3tProperties jets3tProperties, boolean proxyAutodetect,
         String proxyHostAddress, int proxyPort, String proxyUser,
         String proxyPassword, String proxyDomain)
+    {
+        String s3Endpoint = jets3tProperties.getStringProperty(
+                "s3service.s3-endpoint", Constants.S3_DEFAULT_HOSTNAME);
+        initHttpProxy(httpClient, jets3tProperties, proxyAutodetect, proxyHostAddress, proxyPort,
+            proxyUser, proxyPassword, proxyDomain, s3Endpoint);
+    }
+
+    /**
+     * @param httpClient
+     * @param proxyAutodetect
+     * @param proxyHostAddress
+     * @param proxyPort
+     * @param proxyUser
+     * @param proxyPassword
+     * @param proxyDomain
+     * @param endpoint
+     */
+    public static void initHttpProxy(HttpClient httpClient,
+        Jets3tProperties jets3tProperties, boolean proxyAutodetect,
+        String proxyHostAddress, int proxyPort, String proxyUser,
+        String proxyPassword, String proxyDomain, String endpoint)
     {
         HostConfiguration hostConfig = httpClient.getHostConfiguration();
 
@@ -487,12 +491,10 @@ public class RestUtils {
         }
         // If no explicit settings are available, try autodetecting proxies (unless autodetect is disabled)
         else if (proxyAutodetect) {
-            String s3Endpoint = jets3tProperties.getStringProperty(
-                "s3service.s3-endpoint", Constants.S3_DEFAULT_HOSTNAME);
             // Try to detect any proxy settings from applet.
             ProxyHost proxyHost = null;
             try {
-                proxyHost = PluginProxyUtil.detectProxy(new URL("http://" + s3Endpoint));
+                proxyHost = PluginProxyUtil.detectProxy(new URL("http://" + endpoint));
                 if (proxyHost != null) {
                     if (log.isInfoEnabled()) {
                         log.info("Using Proxy: " + proxyHost.getHostName() + ":" + proxyHost.getPort());
@@ -550,10 +552,9 @@ public class RestUtils {
         return timeOffset;
     }
 
-    public static Map convertHeadersToMap(Header[] headers) {
-        Map s3Headers = new HashMap();
-        for (int i = 0; i < headers.length; i++) {
-            Header header = headers[i];
+    public static Map<String, String> convertHeadersToMap(Header[] headers) {
+        Map<String, String> s3Headers = new HashMap<String, String>();
+        for (Header header: headers) {
             s3Headers.put(header.getName(), header.getValue());
         }
         return s3Headers;
