@@ -35,7 +35,6 @@ import java.text.SimpleDateFormat;
 import java.util.Collection;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -50,7 +49,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.jets3t.service.Constants;
 import org.jets3t.service.S3Service;
-import org.jets3t.service.S3ServiceException;
+import org.jets3t.service.ServiceException;
 import org.jets3t.service.model.S3Object;
 import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
@@ -83,17 +82,17 @@ public class ServiceUtils {
         ParseException exception = null;
         synchronized (iso8601DateParser) {
             try {
-            	return iso8601DateParser.parse(dateString);
+                return iso8601DateParser.parse(dateString);
             } catch (ParseException e) {
-            	exception = e;
+                exception = e;
             }
         }
         // Work-around to parse datetime value returned by Walrus
         synchronized (iso8601DateParser_Walrus) {
             try {
-            	return iso8601DateParser_Walrus.parse(dateString);
+                return iso8601DateParser_Walrus.parse(dateString);
             } catch (ParseException e) {
-            	// Ignore work-around exceptions
+                // Ignore work-around exceptions
             }
         }
         // Throw original exception if the Walrus work-around doesn't save us.
@@ -126,14 +125,14 @@ public class ServiceUtils {
      * @param canonicalString
      * canonical string representing the request to sign.
      * @return Signature
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
     public static String signWithHmacSha1(String awsSecretKey, String canonicalString)
-        throws S3ServiceException
+        throws ServiceException
     {
         if (awsSecretKey == null) {
             if (log.isDebugEnabled()) {
-            	log.debug("Canonical string will not be signed, as no AWS Secret Key was provided");
+                log.debug("Canonical string will not be signed, as no AWS Secret Key was provided");
             }
             return null;
         }
@@ -147,7 +146,7 @@ public class ServiceUtils {
             signingKey = new SecretKeySpec(awsSecretKey.getBytes(Constants.DEFAULT_ENCODING),
                 Constants.HMAC_SHA1_ALGORITHM);
         } catch (UnsupportedEncodingException e) {
-            throw new S3ServiceException("Unable to get bytes from secret string", e);
+            throw new ServiceException("Unable to get bytes from secret string", e);
         }
 
         // Acquire the MAC instance and initialize with the signing key.
@@ -171,7 +170,7 @@ public class ServiceUtils {
                 canonicalString.getBytes(Constants.DEFAULT_ENCODING)));
             return new String(b64);
         } catch (UnsupportedEncodingException e) {
-            throw new S3ServiceException("Unable to get bytes from canonical string", e);
+            throw new ServiceException("Unable to get bytes from canonical string", e);
         }
     }
 
@@ -199,12 +198,17 @@ public class ServiceUtils {
         }
         String line = null;
         try {
+            boolean firstLine = true;
             while ((line = br.readLine()) != null) {
-                sb.append(line + "\n");
+                if (!firstLine) {
+                    sb.append("\n");
+                }
+                sb.append(line);
+                firstLine = false;
             }
         } catch (Exception e) {
             if (log.isWarnEnabled()) {
-            	log.warn("Unable to read String from Input Stream", e);
+                log.warn("Unable to read String from Input Stream", e);
             }
         }
         return sb.toString();
@@ -268,38 +272,39 @@ public class ServiceUtils {
     }
 
     /**
-     * From a map of metadata returned from a REST Get Object or Get Object Head request, returns a map
+     * From a map of metadata returned from a REST GET or HEAD request, returns a map
      * of metadata with the HTTP-connection-specific metadata items removed.
      *
      * @param metadata
      * @return
      * metadata map with HTTP-connection-specific items removed.
      */
-    public static Map cleanRestMetadataMap(Map metadata) {
+    public static Map<String, Object> cleanRestMetadataMap(
+        Map<String, Object> metadata, String headerPrefix, String metadataPrefix)
+    {
         if (log.isDebugEnabled()) {
-        	log.debug("Cleaning up REST metadata items");
+            log.debug("Cleaning up REST metadata items");
         }
-        HashMap cleanMap = new HashMap();
+        Map<String, Object> cleanMap = new HashMap<String, Object>();
         if (metadata != null) {
-            Iterator metadataIter = metadata.entrySet().iterator();
-            while (metadataIter.hasNext()) {
-                Map.Entry entry = (Map.Entry) metadataIter.next();
-                Object key = entry.getKey();
+            for (Map.Entry<String, Object> entry: metadata.entrySet()) {
+                String key = entry.getKey();
                 Object value = entry.getValue();
 
                 // Trim prefixes from keys.
                 String keyStr = (key != null ? key.toString() : "");
-                if (keyStr.startsWith(Constants.REST_METADATA_PREFIX)) {
+                if (keyStr.startsWith(metadataPrefix)) {
                     key = keyStr
-                        .substring(Constants.REST_METADATA_PREFIX.length(), keyStr.length());
+                        .substring(metadataPrefix.length(), keyStr.length());
                     if (log.isDebugEnabled()) {
-                        log.debug("Removed Amazon meatadata header prefix from key: " + keyStr
-                            + "=>" + key);
+                        log.debug("Removed meatadata header prefix "
+                            + headerPrefix + " from key: " + keyStr + "=>" + key);
                     }
-                } else if (keyStr.startsWith(Constants.REST_HEADER_PREFIX)) {
-                    key = keyStr.substring(Constants.REST_HEADER_PREFIX.length(), keyStr.length());
+                } else if (keyStr.startsWith(headerPrefix)) {
+                    key = keyStr.substring(headerPrefix.length(), keyStr.length());
                     if (log.isDebugEnabled()) {
-                        log.debug("Removed Amazon header prefix from key: " + keyStr + "=>" + key);
+                        log.debug("Removed Amazon header prefix "
+                            + headerPrefix + " from key: " + keyStr + "=>" + key);
                     }
                 } else if (RestUtils.HTTP_HEADER_METADATA_NAMES.contains(keyStr.toLowerCase(Locale.getDefault()))) {
                     key = keyStr;
@@ -317,7 +322,7 @@ public class ServiceUtils {
                     }
                 } else {
                     if (log.isDebugEnabled()) {
-                    	log.debug("Ignoring metadata item: " + keyStr + "=" + value);
+                        log.debug("Ignoring metadata item: " + keyStr + "=" + value);
                     }
                     continue;
                 }
@@ -325,16 +330,17 @@ public class ServiceUtils {
                 // Convert connection header string Collections into simple strings (where
                 // appropriate)
                 if (value instanceof Collection) {
-                    if (((Collection) value).size() == 1) {
+                    Collection<?> coll = (Collection<?>) value;
+                    if (coll.size() == 1) {
                         if (log.isDebugEnabled()) {
-                        	log.debug("Converted metadata single-item Collection "
-                    			+ value.getClass() + " " + value + " for key: " + key);
+                            log.debug("Converted metadata single-item Collection "
+                                + coll.getClass() + " " + coll + " for key: " + key);
                         }
-                        value = ((Collection) value).iterator().next();
+                        value = coll.iterator().next();
                     } else {
                         if (log.isWarnEnabled()) {
-                        	log.warn("Collection " + value
-                    			+ " has too many items to convert to a single string");
+                            log.warn("Collection " + coll
+                                + " has too many items to convert to a single string");
                         }
                     }
                 }
@@ -343,7 +349,7 @@ public class ServiceUtils {
                 if ("Date".equals(key) || "Last-Modified".equals(key)) {
                     if (!(value instanceof Date)) {
                         if (log.isDebugEnabled()) {
-                        	log.debug("Parsing date string '" + value
+                            log.debug("Parsing date string '" + value
                             + "' into Date object for key: " + key);
                         }
                         try {
@@ -355,7 +361,7 @@ public class ServiceUtils {
                             } catch (ParseException pe2) {
                                 // Log original exception if the work-around fails.
                                 if (log.isWarnEnabled()) {
-                                	log.warn("Date string is not RFC 822 compliant for metadata field " + key, pe);
+                                    log.warn("Date string is not RFC 822 compliant for metadata field " + key, pe);
                                 }
                             }
                         }
@@ -401,6 +407,11 @@ public class ServiceUtils {
      * decoded data from the hex string.
      */
     public static byte[] fromHex(String hexData) {
+        if ((hexData.length() & 1) != 0  ||
+            hexData.replaceAll("[a-fA-F0-9]", "").length() > 0) {
+            throw new java.lang.IllegalArgumentException("'" + hexData + "' is not a hex string");
+        }
+
         byte[] result = new byte[(hexData.length() + 1) / 2];
         String hexNumber = null;
         int stringOffset = 0;
@@ -438,10 +449,10 @@ public class ServiceUtils {
      * @return
      * a delimited string
      */
-    public static String join(List items, String delimiter) {
+    public static String join(List<?> items, String delimiter) {
         StringBuffer sb = new StringBuffer();
         for (int i = 0; i < items.size(); i++) {
-            sb.append(items.get(i));
+            sb.append(items.get(i).toString());
             if (i < items.size() - 1) {
                 sb.append(delimiter);
             }
@@ -549,6 +560,37 @@ public class ServiceUtils {
         return computeMD5Hash(new ByteArrayInputStream(data));
     }
 
+    /**
+     * Guess whether the given ETag value is also an MD5 hash of an underlying object
+     * in a storage service, as opposed to being some other kind of opaque hash.
+     * <p>
+     * This test was made necessary by Amazon S3's multipart upload feature, where
+     * the ETag value returned after a re-assembled multipart upload is completed
+     * is no longer the same as an MD5 hash of the assembled data.
+     * <p>
+     * An ETag is considered also an MD5 when:
+     * <ul>
+     * <li>The length is exactly 16 characters (excluding surrounding quote characters)</li>
+     * <li>All characters in the string are hexadecimal values, i.e. [0-9a-f] when lowercased</li>
+     * </ul>
+     * <p>
+     * These rules are drawn from the post by Carl@AWS on Nov 11, 2010 10:40 AM here:
+     * https://forums.aws.amazon.com/thread.jspa?messageID=222158&tstart=0
+     *
+     * @return
+     * true if the ETag value can be assumed to also be an MD5 hash.
+     */
+    public static boolean isEtagAlsoAnMD5Hash(String etag) {
+        if (etag == null || etag.length() != 32) {
+            return false;
+        }
+        String nonHexChars = etag.toLowerCase().replaceAll("[a-f0-9]", "");
+        if (nonHexChars.length() > 0) {
+            return false;
+        }
+        return true;
+    }
+
     /**
      * Identifies the name of a bucket from a given host name, if available.
      * Returns null if the bucket name cannot be identified, as might happen
@@ -680,14 +722,14 @@ public class ServiceUtils {
      * user agent string. This value may be null.
      * @return
      * a string built with the following components (some elements may not be available):
-     * <tt>jets3t/</tt><i>{@link S3Service#VERSION_NO__JETS3T_TOOLKIT}</i>
+     * <tt>JetS3t/</tt><i>{@link Constants#JETS3T_VERSION}</i>
      * (<i>os.name</i>/<i>os.version</i>; <i>os.arch</i>; <i>user.region</i>;
      * <i>user.region</i>; <i>user.language</i>) <i>applicationDescription</i></tt>
      *
      */
     public static String getUserAgentDescription(String applicationDescription) {
         return
-            "JetS3t/" + S3Service.VERSION_NO__JETS3T_TOOLKIT + " ("
+            "JetS3t/" + Constants.JETS3T_VERSION + " ("
             + System.getProperty("os.name") + "/"
             + System.getProperty("os.version") + ";"
             + " " + System.getProperty("os.arch")
@@ -712,7 +754,7 @@ public class ServiceUtils {
      *
      * @return an initialized XML SAX reader
      */
-    public static XMLReader loadXMLReader() throws S3ServiceException {
+    public static XMLReader loadXMLReader() throws ServiceException {
         // Try loading the default SAX reader
         try {
             return XMLReaderFactory.createXMLReader();
@@ -734,7 +776,7 @@ public class ServiceUtils {
             }
         }
         // If we haven't found and returned an XMLReader yet, give up.
-        throw new S3ServiceException("Failed to initialize a SAX XMLReader");
+        throw new ServiceException("Failed to initialize a SAX XMLReader");
     }
 
 }
