@@ -18,7 +18,7 @@
  */
 package org.jets3t.service.utils.signedurl;
 
-import org.jets3t.service.S3ServiceException;
+import org.jets3t.service.ServiceException;
 import org.jets3t.service.acl.AccessControlList;
 import org.jets3t.service.model.S3Object;
 
@@ -55,9 +55,9 @@ public interface SignedUrlHandler {
      * the S3Object put to S3. The S3Object returned will be identical to the object provided,
      * except that the data input stream (if any) will have been consumed.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public S3Object putObjectWithSignedUrl(String signedPutUrl, S3Object object) throws S3ServiceException;
+    public S3Object putObjectWithSignedUrl(String signedPutUrl, S3Object object) throws ServiceException;
 
     /**
      * Deletes an object using a pre-signed DELETE URL generated for that object.
@@ -69,9 +69,9 @@ public interface SignedUrlHandler {
      * @param signedDeleteUrl
      * a signed DELETE URL.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public void deleteObjectWithSignedUrl(String signedDeleteUrl) throws S3ServiceException;
+    public void deleteObjectWithSignedUrl(String signedDeleteUrl) throws ServiceException;
 
     /**
      * Gets an object using a pre-signed GET URL generated for that object.
@@ -86,9 +86,9 @@ public interface SignedUrlHandler {
      * @return
      * the S3Object in S3 including all metadata and the object's data input stream.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public S3Object getObjectWithSignedUrl(String signedGetUrl) throws S3ServiceException;
+    public S3Object getObjectWithSignedUrl(String signedGetUrl) throws ServiceException;
 
     /**
      * Gets an object's details using a pre-signed HEAD URL generated for that object.
@@ -103,9 +103,9 @@ public interface SignedUrlHandler {
      * @return
      * the S3Object in S3 including all metadata, but without the object's data input stream.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public S3Object getObjectDetailsWithSignedUrl(String signedHeadUrl) throws S3ServiceException;
+    public S3Object getObjectDetailsWithSignedUrl(String signedHeadUrl) throws ServiceException;
 
     /**
      * Gets an object's ACL details using a pre-signed GET URL generated for that object.
@@ -117,9 +117,9 @@ public interface SignedUrlHandler {
      * @return
      * the AccessControlList settings of the object in S3.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public AccessControlList getObjectAclWithSignedUrl(String signedAclUrl) throws S3ServiceException;
+    public AccessControlList getObjectAclWithSignedUrl(String signedAclUrl) throws ServiceException;
 
     /**
      * Sets an object's ACL details using a pre-signed PUT URL generated for that object.
@@ -130,8 +130,8 @@ public interface SignedUrlHandler {
      * @param acl
      * the ACL settings to apply to the object represented by the signed URL.
      *
-     * @throws S3ServiceException
+     * @throws ServiceException
      */
-    public void putObjectAclWithSignedUrl(String signedAclUrl, AccessControlList acl) throws S3ServiceException;
+    public void putObjectAclWithSignedUrl(String signedAclUrl, AccessControlList acl) throws ServiceException;
 
 }
