@@ -40,7 +40,7 @@ import org.jets3t.servlets.gatekeeper.impl.DefaultUrlSigner;
 
 /**
  * A servlet implementation of an S3 Gatekeeper, as described in the document
- * <a href="http://jets3t.s3.amazonaws.com/applications/gatekeeper-concepts.html">
+ * <a href="http://www.jets3t.org/applications/gatekeeper-concepts.html">
  * Gatekeeper Concepts</a>.
  * <p>
  * This servlet offers an easily configurable and extensible approach, where key
@@ -58,7 +58,7 @@ import org.jets3t.servlets.gatekeeper.impl.DefaultUrlSigner;
  * unconfigured the default JetS3t implementations are used.
  * <p>
  * For more information about this servlet please refer to:
- * <a href="http://jets3t.s3.amazonaws.com/applications/gatekeeper.html">
+ * <a href="http://www.jets3t.org/applications/gatekeeper.html">
  * JetS3t Gatekeeper</a>
  *
  * @author James Murty
@@ -108,6 +108,7 @@ public class GatekeeperServlet extends HttpServlet {
      * Initialises the pluggable implementation classes for {@link Authorizer},
      * {@link TransactionIdProvider}, and {@link UrlSigner}
      */
+    @Override
     public void init(ServletConfig servletConfig) throws ServletException {
         if (log.isInfoEnabled()) {
             log.info("Initialising GatekeeperServlet");
@@ -225,6 +226,7 @@ public class GatekeeperServlet extends HttpServlet {
     /**
      * Sends a simple HTML page in response to GET requests, indicating that the servlet is running.
      */
+    @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
         if (log.isDebugEnabled()) {
             log.debug("Handling GET request");
@@ -233,8 +235,8 @@ public class GatekeeperServlet extends HttpServlet {
         response.setContentType("text/html");
         response.getWriter().println("<html><head><title>JetS3t Gatekeeper</title><body>");
         response.getWriter().println("<p>JetS3t Gatekeeper is running " +
-        	(isInitCompleted? "and initialized successfully" : "but <b>initialization failed</b>")
-        	+ "</p></body></html>");
+            (isInitCompleted? "and initialized successfully" : "but <b>initialization failed</b>")
+            + "</p></body></html>");
     }
 
     /**
@@ -242,6 +244,7 @@ public class GatekeeperServlet extends HttpServlet {
      * sends a plain text response document containing the Gatekeeper response message encoded as
      * a properties file.
      */
+    @Override
     public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
         if (log.isDebugEnabled()) {
             log.debug("Handling POST request");
@@ -268,10 +271,10 @@ public class GatekeeperServlet extends HttpServlet {
                 if (log.isWarnEnabled()) {
                     log.warn("Cannot process POST request as Gatekeeper servlet did not initialize correctly");
                 }
-            	gatekeeperMessage.addApplicationProperty(
+                gatekeeperMessage.addApplicationProperty(
                         GatekeeperMessage.APP_PROPERTY_GATEKEEPER_ERROR_CODE, "GatekeeperInitializationError");
             } else if (gatekeeperMessage.getApplicationProperties().containsKey(
-                	GatekeeperMessage.LIST_OBJECTS_IN_BUCKET_FLAG))
+                    GatekeeperMessage.LIST_OBJECTS_IN_BUCKET_FLAG))
             {
                 // Handle "limited listing" requests.
                 if (log.isDebugEnabled()) {
@@ -279,16 +282,16 @@ public class GatekeeperServlet extends HttpServlet {
                 }
                 boolean allowed = authorizer.allowBucketListingRequest(gatekeeperMessage, clientInformation);
                 if (allowed) {
-                	bucketLister.listObjects(gatekeeperMessage, clientInformation);
+                    bucketLister.listObjects(gatekeeperMessage, clientInformation);
                 }
             } else {
                 if (log.isDebugEnabled()) {
                     log.debug("Processing " + gatekeeperMessage.getSignatureRequests().length
-                    		+ " object signature requests");
+                            + " object signature requests");
                 }
                 // Process each signature request.
                 for (int i = 0; i < gatekeeperMessage.getSignatureRequests().length; i++) {
-                    SignatureRequest signatureRequest = (SignatureRequest) gatekeeperMessage.getSignatureRequests()[i];
+                    SignatureRequest signatureRequest = gatekeeperMessage.getSignatureRequests()[i];
 
                     // Determine whether the request will be allowed. If the request is not allowed, the
                     // reason will be made available in the signature request object (with signatureRequest.declineRequest())
